{% extends 'shatailadmin/bulk_actions/confirmation/base.html' %} {% load i18n shatailusers_tags shatailadmin_tags %} {% block titletag %}{% blocktrans trimmed count counter=items|length %}Delete 1 user {% plural %}Delete {{ counter }} users{% endblocktrans
%}{% endblock %} {% block header %} {% trans "Delete" as del_str %} {% include "shatailadmin/shared/header.html" with title=del_str icon="doc-empty-inverse" %} {% endblock header %} {% block items_with_access %} {% if items %}
<p>{% trans "Are you sure you want to delete these users?" %}</p>
<ul>
    {% for user in items %}
    <li>
        <a href="{% url 'shatailusers_users:edit' user.item.pk %}" target="_blank" rel="noreferrer">{{user.item|user_display_name }}</a>
    </li>
    {% endfor %}
</ul>
{% endif %} {% endblock items_with_access %} {% block items_with_no_access %} {% blocktrans trimmed asvar no_access_msg count counter=items_with_no_access|length %}You don't have permission to delete this user{% plural %}You don't have permission to delete
these users{% endblocktrans %} {% include 'shatailusers/bulk_actions/list_items_with_no_access.html' with items=items_with_no_access no_access_msg=no_access_msg %} {% endblock items_with_no_access %} {% block form_section %} {% if items %} {% trans 'Yes,
delete' as action_button_text %} {% trans "No, don't delete" as no_action_button_text %} {% include 'shatailadmin/bulk_actions/confirmation/form.html' with action_button_class="serious" %} {% else %} {% include 'shatailadmin/bulk_actions/confirmation/go_back.html'
%} {% endif %} {% endblock form_section %}