{% extends "shatailadmin/shared/field.html" %} {% load i18n %} {% block form_field %}
<a href="{{ document.url }}" class="icon icon-doc-full-inverse">{{ document.filename }}</a><br /><br /> {% trans "Change document:" %} {{ field }} {% endblock %}