{% extends "shatailadmin/base.html" %} {% load i18n %} {% block titletag %}{% blocktrans trimmed with query=query.query_string %}Delete {{ query }}{% endblocktrans %}{% endblock %} {% block content %} {% trans "Delete" as delete_str %} {% include "shatailadmin/shared/header.html"
with title=delete_str subtitle=query.query_string %}

<div class="nice-padding">
    <p>{% trans "Are you sure you want to delete all promoted results for this search term?" %}</p>
    <form action="{% url 'shatailsearchpromotions:delete' query.id %}" method="POST">
        {% csrf_token %}
        <input type="submit" value="{% trans 'Yes, delete' %}" class="button serious" />
    </form>
</div>
{% endblock %}