{% extends "shatailadmin/widgets/chooser.html" %} {% load shatailadmin_tags shatailimages_tags %} {% block unchosen_icon %}{% icon name="image" %}{% endblock unchosen_icon %} {# Image chooser doesn't have a chosen icon. It shows an preview of the chosen
image instead .#} {% block chosen_icon %}{% endblock chosen_icon %} {% block chooser_class %}image-chooser{% endblock %} {% block chooser_attributes %}data-chooser-url="{% url "shatailimages:chooser" %}"{% endblock %} {% block chosen_state_view %}
<div class="preview-image">
    <img alt="{{ title }}" class="show-transparency" height="{{ preview.height }}" src="{{ preview.url }}" title="{{ title }}" width="{{ preview.width }}">
</div>
{% endblock %}