{% extends "shatailadmin/userbar/item_base.html" %} {% load i18n shatailadmin_tags %} {% block item_content %}
<form action="{% url 'shatailadmin_pages:reject_moderation' self.revision.id %}" target="_parent" method="post">
    {% csrf_token %}
    <button type="submit" value="{% trans 'Reject' %}" class="button" role="menuitem">
            {% icon name="cross" class_name="shatail-action-icon" %}
            {% trans 'Reject' %}
        </button>
</form>
{% endblock %}