{% extends 'shatailadmin/bulk_actions/confirmation/base.html' %} {% load i18n %} {% load shatailimages_tags shatailadmin_tags %} {% block titletag %}{% blocktrans trimmed count counter=items|length %}Add 1 document to new collection {% plural %}Add {{
counter }} documents to new collection{% endblocktrans %}{% endblock %} {% block header %} {% trans "Add documents to collection" as add_str %} {% include "shatailadmin/shared/header.html" with title=add_str icon="doc-full-inverse" %} {% endblock header
%} {% block items_with_access %} {% if items %}
<p>
    {% blocktrans trimmed count counter=items|length %} Are you sure you want to add the following document to the selected collection? {% plural %} Are you sure you want to add the following documents to the selected collection? {% endblocktrans %}
</p>
<ul>
    {% for document in items %}
    <li>
        <a href="{% url 'shataildocs:edit' document.item.id %}" target="_blank" rel="noreferrer">{{document.item.title}}</a>
    </li>
    {% endfor %}
</ul>
{% endif %} {% endblock items_with_access %} {% block items_with_no_access %} {% blocktrans trimmed asvar no_access_msg count counter=items_with_no_access|length %}You don't have permission to add this document to a collection{% plural %}You don't have
permission to add these documents to a collection{% endblocktrans %} {% include 'shataildocs/bulk_actions/list_items_with_no_access.html' with items=items_with_no_access no_access_msg=no_access_msg %} {% endblock items_with_no_access %} {% block form_section
%} {% if items %} {% trans 'Yes, add' as action_button_text %} {% trans "No, don't add" as no_action_button_text %} {% include 'shatailadmin/bulk_actions/confirmation/form_with_fields.html' %} {% else %} {% include 'shatailadmin/bulk_actions/confirmation/go_back.html'
%} {% endif %} {% endblock form_section %}