{% extends "shatailadmin/base.html" %} {% load i18n %} {% block titletag %}{% blocktrans trimmed with name=workflow.name %}Pages that use workflow '{{ name }}'{% endblocktrans %}{% endblock %} {% block content %} {% trans "Pages that use workflow" as
usage_str %} {% include "shatailadmin/shared/header.html" with title=usage_str subtitle=workflow.name %}

<div class="nice-padding">
    <table class="listing">
        <col />
        <col width="30%" />
        <col width="15%" />
        <col width="15%" />
        <thead>
            <tr>
                <th class="title">{% trans "Title" %}</th>
                <th>{% trans "Parent" %}</th>
                <th>{% trans "Type" %}</th>
                <th>{% trans "Status" %}</th>
            </tr>
        </thead>
        <tbody>
            {% for page in used_by %}
            <tr>
                <td class="title" valign="top">
                    <div class="title-wrapper"><a href="{% url 'shatailadmin_pages:edit' page.id %}" title="{% trans 'Edit this page' %}">{{ page.get_admin_display_title }}</a></div>
                </td>
                <td>
                    {% if page.get_parent %}
                    <a href="{% url 'shatailadmin_explore' page.get_parent.id %}">{{ page.get_parent.specific_deferred.get_admin_display_title }}</a> {% endif %}
                </td>
                <td>
                    {{ page.content_type.model_class.get_verbose_name }}
                </td>
                <td>
                    {% include "shatailadmin/shared/page_status_tag.html" with page=page %}
                </td>
            </tr>
            {% endfor %}
        </tbody>
    </table>
</div>
{% include "shatailadmin/shared/pagination_nav.html" with items=used_by %} {% endblock %}