{% extends "shatailadmin/base.html" %} {% load i18n shatailadmin_tags %} {% block titletag %}{{ view.page_title }}{% endblock %} {% block extra_css %} {{ block.super }} {% include "shatailadmin/pages/_editor_css.html" %} {% endblock %} {% block extra_js
%} {{ block.super }} {% include "shatailadmin/pages/_editor_js.html" %} {% endblock %} {% block content %} {% include "shatailadmin/shared/header.html" with title=view.page_title icon=view.header_icon only %}

<form action="{{ view.get_add_url }}" enctype="multipart/form-data" method="POST" novalidate>
    {% csrf_token %}

    <ul class="fields nice-padding">
        {% for field in form %} {% if not field.is_hidden %} {% include "shatailadmin/shared/field_as_li.html" %} {% else %} {{ field }} {% endif %} {% endfor %}
    </ul>

    {% block footer %}
    <footer class="footer" role="contentinfo">
        <ul>
            <li class="actions footer__container">
                {% block form_actions %}
                <div class="dropdown dropup dropdown-button match-width">
                    <button type="submit" class="button action-save button-longrunning" data-clicked-text="{% trans 'Creating…' %}">
                                    {% icon name="spinner" %}<em>{% trans 'Create' %}</em>
                                </button>
                </div>
                {% endblock %}
            </li>
        </ul>
    </footer>
    {% endblock %}
</form>
{% endblock %}