{% extends 'shatailadmin/bulk_actions/confirmation/base.html' %} {% load i18n %} {% load shatailimages_tags shatailadmin_tags %} {% block titletag %}{% blocktrans trimmed count counter=items|length %}Add tags to 1 document {% plural %}Add tags to {{ counter
}} documents{% endblocktrans %}{% endblock %} {% block extra_js %} {{ block.super }} {% url 'shatailadmin_tag_autocomplete' as autocomplete_url %}
<script>
    $(function() {
        $('#id_tags').tagit({
            autocomplete: {
                source: "{{ autocomplete_url|addslashes }}"
            }
        });
    });
</script>
{% endblock %} {% block header %} {% trans "Add tags to documents" as add_str %} {% include "shatailadmin/shared/header.html" with title=add_str icon="doc-full-inverse" %} {% endblock header %} {% block items_with_access %} {% if items %}
<p>
    {% blocktrans trimmed count counter=items|length %} Are you sure you want to tag the following document? {% plural %} Are you sure you want to tag the following documents? {% endblocktrans %}
</p>
<ul>
    {% for document in items %}
    <li>
        <a href="{% url 'shataildocs:edit' document.item.id %}" target="_blank" rel="noreferrer">{{document.item.title}}</a>
    </li>
    {% endfor %}
</ul>
{% endif %} {% endblock items_with_access %} {% block items_with_no_access %} {% blocktrans trimmed asvar no_access_msg count counter=items_with_no_access|length %}You don't have permission to add tags to this document{% plural %}You don't have permission
to add tags to these documents{% endblocktrans %} {% include 'shataildocs/bulk_actions/list_items_with_no_access.html' with items=items_with_no_access no_access_msg=no_access_msg %} {% endblock items_with_no_access %} {% block form_section %} {% if items
%} {% trans 'Yes, add' as action_button_text %} {% trans "No, don't add" as no_action_button_text %} {% include 'shatailadmin/bulk_actions/confirmation/form_with_fields.html' %} {% else %} {% include 'shatailadmin/bulk_actions/confirmation/go_back.html'
%} {% endif %} {% endblock form_section %}