{% extends "shatailadmin/generic/create.html" %} {% load shatailadmin_tags %} {% block extra_js %} {{ block.super }}
<script src="{% versioned_static 'shatailadmin/js/modal-workflow.js' %}"></script>
{% endblock %}