{% extends 'shatailadmin/bulk_actions/confirmation/list_items_with_no_access.html' %} {% load i18n %} {% block per_item %} {% if item.can_edit %}
<a href="{% url 'shatailimages:edit' item.item.id %}" target="_blank" rel="noreferrer">{{ item.item.title }}</a> {% else %} {{ item.item.title }} {% endif %} {% endblock per_item %}