{% load i18n %} {% if items %} {% if is_searching %}
<h2 role="alert">
    {% blocktrans trimmed count counter=items.paginator.count %} There is {{ counter }} match {% plural %} There are {{ counter }} matches {% endblocktrans %}
</h2>
{% endif %} {% include "shatailsnippets/snippets/list.html" %} {% url 'shatailsnippets:list' model_opts.app_label model_opts.model_name as shatailsnippets_list_url %} {% include "shatailadmin/shared/pagination_nav.html" with items=items linkurl=shatailsnippets_list_url
%} {% else %} {% if is_searching %}
<p role="alert">{% blocktrans trimmed %}Sorry, no snippets match "<em>{{ query_string }}</em>"{% endblocktrans %}</p>
{% else %} {% url 'shatailsnippets:add' model_opts.app_label model_opts.model_name as shatailsnippets_create_url %} {# NOTE: The two strings in the following messages are exactly the same #} {# The difference is that the first variant appends '?locale={{
locale.language_code}}' to 'shatailsnippets_create_url' #} {% if locale %}
<p class="no-results-message">{% blocktrans trimmed with snippet_type_name_plural=model_opts.verbose_name_plural shatailsnippets_create_url=shatailsnippets_create_url|add:'?locale='|add:locale.language_code %}No {{ snippet_type_name_plural }} have been created. Why not <a href="{{ shatailsnippets_create_url }}">add one</a>?{%
    endblocktrans %}</p>
{% else %}
<p class="no-results-message">{% blocktrans trimmed with snippet_type_name_plural=model_opts.verbose_name_plural %}No {{ snippet_type_name_plural }} have been created. Why not <a href="{{ shatailsnippets_create_url }}">add one</a>?{% endblocktrans %}</p>
{% endif %} {% endif %} {% endif %}