{% if create_form %} {% include "shatailadmin/workflows/task_chooser/includes/create_form.html" %} {% else %} {% include "shatailadmin/workflows/task_chooser/includes/select_task_type.html" %} {% endif %}