{% extends 'shatailadmin/reports/base_report.html' %} {% load i18n shatailadmin_tags %} {% block results %} {% if object_list %} {% include "shatailredirects/list.html" with redirects=object_list %} {% else %}
<p>{% trans "No redirects found." %}</p>
{% endif %} {% endblock %} {% block no_results %}
<p>{% trans "No redirects found." %}</p>
{% endblock %}