{% load i18n %} {% if form_pages %} {% include "shatailforms/list_forms.html" %} {% include "shatailadmin/shared/pagination_nav.html" with items=page_obj linkurl="shatailforms:index" %} {% else %}
<p>{% trans "No form pages have been created." %}</p>
{% endif %}