{% extends "shatailadmin/base.html" %} {% load i18n %} {% block titletag %}{% trans "Forms" %}{% endblock %} {% block content %} {% trans "Forms" as forms_str %} {% trans "Pages" as select_form_str %} {% include "shatailadmin/shared/header_with_locale_selector.html"
with title=forms_str subtitle=select_form_str icon="form" %}

<div class="nice-padding">
    <div id="form-results" class="forms">
        {% include "shatailforms/results_forms.html" %}
    </div>
</div>
{% endblock %}