{% load shatailadmin_tags %}
<script src="{% versioned_static 'shatailadmin/js/expanding-formset.js' %}"></script>
<script src="{% versioned_static 'shatailadmin/js/modal-workflow.js' %}"></script>
<script src="{% versioned_static 'shatailusers/js/group-form.js' %}"></script>

{{ form_media.js }}