{% load shatailuserbar %} {% load i18n %} {% get_current_language as LANGUAGE_CODE %} {% get_current_language_bidi as LANGUAGE_BIDI %}
<!DOCTYPE HTML>
<html lang="{{ LANGUAGE_CODE }}" dir="{% if LANGUAGE_BIDI %}rtl{% else %}ltr{% endif %}">

<head>
    <title>{% block html_title %}{{ self.title }}{% endblock %}</title>
</head>

<body>
    {% shatailuserbar %}
    <h1>{{ self.title }}</h1>
    {% block content %}{% endblock %}
</body>

</html>