{% load i18n shatailadmin_tags %}

<ul class="breadcrumb">
    {% if show_locale_labels %}
    <li class="breadcrumb-item">
        {% if locale_options %} {% if selected_locale %} {% include "shatailadmin/shared/locale_selector.html" with translations=locale_options locale=selected_locale only %} {% else %} {% include "shatailadmin/shared/locale_selector.html" with translations=locale_options
        locale=page.locale only %} {% endif %} {% else %}
        <div class="c-dropdown t-inverted {{ class }}" style="display: inline-block;">
            <div aria-label="{{ page.locale.get_display_name }}" class="c-dropdown__button u-btn-current">
                {% icon name="site" class_name="default" %} {{ page.locale.get_display_name }}
            </div>
        </div>
        {% endif %}
    </li>
    {% endif %} {% for page in page.get_ancestors.specific %} {% url 'shatailadmin_choose_page_child' page.id as choose_page_child_url %} {% if page.is_root %} {% trans 'Home' as home %}
    <li class="breadcrumb-item home"><a href="{{ choose_page_child_url }}{% querystring p=None %}" class="breadcrumb-link navigate-pages">{% icon name="home" class_name="home_icon" title=home %}{% icon name="arrow-right" class_name="arrow_right_icon" %}</a></li>
    {% elif forloop.last %}
    <li class="breadcrumb-item"><a href="{{ choose_page_child_url }}{% querystring p=None %}" class="breadcrumb-link navigate-pages">{{ page.get_admin_display_title }}</a></li>
    {% else %}
    <li class="breadcrumb-item"><a href="{{ choose_page_child_url }}{% querystring p=None %}" class="breadcrumb-link navigate-pages"><span class="title">{{ page.get_admin_display_title }}</span>{% icon name="arrow-right" class_name="arrow_right_icon" %}</a></li>
    {% endif %} {% endfor %}
</ul>