{% extends "shatailadmin/base.html" %} {% load shatailadmin_tags i18n %} {% block titletag %}{% trans "Dashboard" %}{% endblock %} {% block bodyclass %}homepage{% endblock %} {% block extra_css %} {{ block.super }}

<link rel="stylesheet" href="{% versioned_static 'shatailadmin/css/layouts/home.css' %}" type="text/css" />
<link rel="stylesheet" href="{% versioned_static 'shatailadmin/css/layouts/page-editor.css' %}" /> {{ media.css }} {% endblock %} {% block content %}
<header class="merged nice-padding">
    <div class="row">
        <div class="col1">
            <div class="avatar"><img src="{% avatar_url user %}" alt="" /></div>
        </div>
        <div class="col9">
            <h1>{% block branding_welcome %}{% blocktrans trimmed %}Welcome to the {{ site_name }} Shatail CMS{% endblocktrans %}{% endblock %}</h1>
            <div class="user-name">{{ user|user_display_name }}</div>
        </div>
    </div>
</header>

{% if panels %} {% for panel in panels %} {% component panel fallback_render_method=True %} {% endfor %} {% else %}
<p>{% trans "This is your dashboard on which helpful information about content you've created will be displayed." %}</p>
{% endif %} {% endblock %} {% block extra_js %} {{ block.super }}
<script src="{% versioned_static 'shatailadmin/js/collapsible.js' %}"></script>
{{ media.js }} {% endblock %}