{% templatetag openblock %} load static shatailcore_tags shatailuserbar {% templatetag closeblock %}

<!DOCTYPE html>
<html lang="en">

<head>
    <meta charset="utf-8" />
    <title>
        {% templatetag openblock %} block title %} {% templatetag openblock %} if page.seo_title %}{% templatetag openvariable %} page.seo_title {% templatetag closevariable %}{% templatetag openblock %} else %}{% templatetag openvariable %} page.title {% templatetag
        closevariable %}{% templatetag openblock %} endif %} {% templatetag openblock %} endblock %} {% templatetag openblock %} block title_suffix %} {% templatetag openblock %} shatail_site as current_site %} {% templatetag openblock %} if current_site
        and current_site.site_name %}- {% templatetag openvariable %} current_site.site_name {% templatetag closevariable %}{% templatetag openblock %} endif %} {% templatetag openblock %} endblock %}
    </title>
    <meta name="description" content="" />
    <meta name="viewport" content="width=device-width, initial-scale=1" /> {% templatetag opencomment %} Global stylesheets {% templatetag closecomment %}
    <link rel="stylesheet" type="text/css" href="{% templatetag openblock %} static 'css/{{ project_name }}.css' {% templatetag closeblock %}"> {% templatetag openblock %} block extra_css {% templatetag closeblock %} {% templatetag opencomment %} Override this in templates to add extra stylesheets {% templatetag closecomment %} {% templatetag openblock %} endblock {% templatetag closeblock
    %}
</head>

<body class="{% templatetag openblock %} block body_class {% templatetag closeblock %}{% templatetag openblock %} endblock {% templatetag closeblock %}">
    {% templatetag openblock %} shatailuserbar {% templatetag closeblock %} {% templatetag openblock %} block content {% templatetag closeblock %}{% templatetag openblock %} endblock {% templatetag closeblock %} {% templatetag opencomment %} Global javascript
    {% templatetag closecomment %}
    <script type="text/javascript" src="{% templatetag openblock %} static 'js/{{ project_name }}.js' {% templatetag closeblock %}"></script>

    {% templatetag openblock %} block extra_js {% templatetag closeblock %} {% templatetag opencomment %} Override this in templates to add extra javascript {% templatetag closecomment %} {% templatetag openblock %} endblock {% templatetag closeblock %}
</body>

</html>