{% extends "shatailadmin/base.html" %} {% load i18n shatailadmin_tags %} {% block titletag %}{% blocktrans trimmed %}Editing {{ setting_type_name}} - {{ instance }}{% endblocktrans %}{% endblock %} {% block bodyclass %}menu-settings{% endblock %} {% block
content %}
<header class="nice-padding merged">
    <div class="row">
        <div class="left">
            <div class="col">
                <h1>
                    {% icon name="cogs" class_name="header-title-icon" %} {% trans "Editing" %}
                    <span>{{ setting_type_name|capfirst }}</span>
                </h1>
            </div>
        </div>
        <div class="right">
            {% if site_switcher %}
            <div class="field choice_field">
                <form method="get" class="setting-site-switch-form" id="settings-site-switch" novalidate>
                    <label for="{{ site_switcher.site.id_for_label }}">
                                {% trans "Site" %}:
                            </label>
                    <div class="input">
                        {{ site_switcher.site }}
                        <span></span>
                    </div>
                </form>
            </div>
            {% endif %}
        </div>
    </div>
</header>

<form action="{% url 'shatailsettings:edit' opts.app_label opts.model_name site.pk %}" method="POST" novalidate{% if form.is_multipart %} enctype="multipart/form-data" {% endif %}>
    {% csrf_token %} {{ edit_handler.render_form_content }}

    <footer class="footer">
        <ul>
            <li class="actions dropdown dropup match-width footer__container">
                <button type="submit" class="button button-longrunning" data-clicked-text="{% trans 'Saving…' %}">{% icon name="spinner" %}<em>{% trans 'Save' %}</em></button>
            </li>
        </ul>
    </footer>
</form>

{% endblock %} {% block extra_css %} {{ block.super }} {% include "shatailadmin/pages/_editor_css.html" %} {{ media.css }} {% endblock %} {% block extra_js %} {{ block.super }} {% include "shatailadmin/pages/_editor_js.html" %} {{ media.js }} {% endblock
%}