{% extends "shatailadmin/base.html" %} {% load shatailusers_tags shatailadmin_tags i18n %} {% block titletag %}{% trans "Editing" %} {{ group.name }}{% endblock %} {% block extra_css %} {{ block.super }}

<link rel="stylesheet" href="{% versioned_static 'shatailusers/css/groups_edit.css' %}" type="text/css" /> {{ form_media.css }} {% endblock %} {% block content %} {% trans "Editing" as editing_str %} {% trans "View users in this group" as users_str %} {% url 'shatailusers_groups:users' group.id as group_users_url %} {% include "shatailadmin/shared/header.html"
with title=editing_str action_icon="user" action_url=group_users_url action_text=users_str subtitle=group.name icon="group" %}

<div class="nice-padding">
    <form action="{% url 'shatailusers_groups:edit' group.id %}" method="POST" novalidate>
        {% csrf_token %}

        <ul class="fields">
            {% block fields %} {% include "shatailadmin/shared/field_as_li.html" with field=form.name %} {% block extra_fields %}{% endblock extra_fields %} {% endblock fields %}

            <li>
                {% format_permissions permission_bound_field=form.permissions %}
            </li>

            {% for panel in permission_panels %}
            <li>
                {{ panel.as_admin_panel }}
            </li>
            {% endfor %}
            <li>
                <input type="submit" value="{% trans 'Save' %}" class="button" /> {% if perms.auth.delete_group %}
                <a href="{% url 'shatailusers_groups:delete' group.id %}" class="button button-secondary no">{% trans "Delete group" %}</a> {% endif %}
            </li>
        </ul>

    </form>
</div>
{% endblock %} {% block extra_js %} {{ block.super }} {% include "shatailusers/groups/includes/group_form_js.html" %} {% endblock %}