{% extends "shatailadmin/base.html" %} {% load shatailadmin_tags i18n %} {% block titletag %}{% blocktrans trimmed with title=document.title %}Delete {{ title }}{% endblocktrans %}{% endblock %} {% block content %} {% trans "Delete document" as del_str
%} {% include "shatailadmin/shared/header.html" with title=del_str subtitle=document.title icon="doc-full-inverse" %}

<div class="nice-padding">

    {% usage_count_enabled as uc_enabled %} {% if uc_enabled %}
    <div class="usagecount">
        <a href="{{ document.usage_url }}">{% blocktrans trimmed count usage_count=document.get_usage.count %}Used {{ usage_count }} time{% plural %}Used {{ usage_count }} times{% endblocktrans %}</a>
    </div>
    {% endif %}

    <p>
        {# This message will only appear in the singular, but we specify a plural so it can share the translation string with confirm_bulk_delete.html #} {% blocktrans trimmed count counter=1 %} Are you sure you want to delete this document? {% plural %} Are
        you sure you want to delete these documents? {% endblocktrans %}
    </p>
    <form action="{% url 'shataildocs:delete' document.id %}" method="POST">
        {% csrf_token %}
        <input type="hidden" value="{{ next }}" name="next">
        <input type="submit" value='{% trans "Yes, delete" %}' class="button serious" />
        <a href="{% url 'shataildocs:index' %}" class="button button-secondary">{% trans "No, don't delete" %}</a>
    </form>
</div>
{% endblock %}