{% load i18n shatailadmin_tags %} {% if documents %} {% if is_searching %}
<h2 role="alert">
    {% blocktrans trimmed count counter=documents.paginator.count %} There is {{ counter }} match {% plural %} There are {{ counter }} matches {% endblocktrans %}
</h2>
{% else %}
<h2>{% trans "Latest documents" %}</h2>
{% endif %} {% component table %} {% include "shatailadmin/shared/pagination_nav.html" with items=documents linkurl='shataildocs:chooser_results' %} {% else %} {% if documents_exist %}
<p role="alert">{% blocktrans trimmed %}Sorry, no documents match "<em>{{ query_string }}</em>"{% endblocktrans %}</p>
{% else %}
<p>
    {% if collection_id %} {% trans "You haven't uploaded any documents in this collection." %} {% else %} {% trans "You haven't uploaded any documents." %} {% endif %} {% if uploadform %} {% blocktrans trimmed %} Why not <a class="upload-one-now" href="#tab-upload"
        role="tab">upload one now</a>? {% endblocktrans %} {% endif %}
</p>
{% endif %} {% endif %}