{% extends "shatailadmin/base.html" %} {% load shatailadmin_tags i18n %} {% block titletag %}Documents{% endblock %} {% block extra_js %} {{ block.super }}
<script>
    window.headerSearch = {
        url: "{% url 'shataildocs:listing_results' %}",
        termInput: "#id_q",
        targetOutput: "#document-results"
    }

    $(function() {
        $('#collection_chooser_collection_id').on('change', function() {
            this.form.submit();
        })
    });
</script>
<script>
    window.shatailConfig.BULK_ACTION_ITEM_TYPE = 'DOCUMENT';
</script>
<script defer src="{% versioned_static 'shatailadmin/js/bulk-actions.js' %}"></script>
{% endblock %} {% block content %} {% trans "Documents" as doc_str %} {% if user_can_add %} {% trans "Add a document" as add_doc_str %} {% url "shataildocs:add_multiple" as add_link %} {% include "shatailadmin/shared/header.html" with title=doc_str action_url=add_link
icon="doc-full-inverse" action_text=add_doc_str search_url="shataildocs:index" %} {% else %} {% include "shatailadmin/shared/header.html" with title=doc_str icon="doc-full-inverse" search_url="shataildocs:index" %} {% endif %}

<div class="nice-padding">
    {% if collections %}
    <form class="image-search search-bar" action="{% url 'shataildocs:index' %}" method="GET" novalidate>
        <ul class="fields">
            {% include "shatailadmin/shared/collection_chooser.html" %}
        </ul>
    </form>
    {% endif %}

    <div id="document-results" class="documents">
        {% include "shataildocs/documents/results.html" %}
    </div>
</div>
{% trans "Select all documents in listing" as select_all_text %} {% include 'shatailadmin/bulk_actions/footer.html' with select_all_obj_text=select_all_text app_label=app_label model_name=model_name objects=documents %} {% endblock %}