@import '../../../../../../client/scss/settings';
@import '../../../../../../client/scss/tools';

.breadcrumb {
  margin: -1.2em 0 2em;
}

@include media-breakpoint-up(sm) {
  .breadcrumb {
    margin-top: -1.8em;
  }
}
