{% extends "shatailadmin/userbar/item_base.html" %}
{% load i18n shatailadmin_tags %}

{% block item_content %}
    <a href="{% url 'shatailadmin_pages:edit' self.page.id %}" target="_parent" role="menuitem">
        {% icon name="edit" class_name="shatail-action-icon" %}
        {% trans 'Edit this page' %}
    </a>
{% endblock %}
