# Generated by Django 3.0.9 on 2020-08-12 20:27

from django.db import migrations
import shatail.blocks
import shatail.fields
import shatail.test.testapp.models


class Migration(migrations.Migration):

    dependencies = [
        ("tests", "0055_eventpage_childobject_i18n"),
    ]

    operations = [
        migrations.AlterField(
            model_name="streampage",
            name="body",
            field=shatail.fields.StreamField(
                [
                    ("text", shatail.blocks.CharBlock()),
                    ("rich_text", shatail.blocks.RichTextBlock()),
                    ("image", shatail.test.testapp.models.ExtendedImageChooserBlock()),
                    (
                        "product",
                        shatail.blocks.StructBlock(
                            [
                                ("name", shatail.blocks.CharBlock()),
                                ("price", shatail.blocks.CharBlock()),
                            ]
                        ),
                    ),
                    ("raw_html", shatail.blocks.RawHTMLBlock()),
                    (
                        "books",
                        shatail.blocks.StreamBlock(
                            [
                                ("title", shatail.blocks.CharBlock()),
                                ("author", shatail.blocks.CharBlock()),
                            ]
                        ),
                    ),
                ]
            ),
        ),
    ]
