{% extends "shatailadmin/shared/header.html" %} {% block right_column_classname %}right col{% endblock %} {% block right_column %}
<form> {# HACK Removes list-style-type #}
    <ul class="fields row rowflush">
        {% if locale %}
        <li class="col">
            <div class="field">
                {% include 'shatailadmin/shared/locale_selector.html' with class='c-dropdown--large w-bg-primary' %}
            </div>
        </li>
        {% endif %}
    </ul>
</form>
{{ block.super }} {% endblock %}