{% load i18n shatailadmin_tags %}
<h2>{% trans "Page permissions" %}</h2>

{{ formset.management_form }} {% if formset.non_form_errors %}
<p class="error-message">
    {% for error in formset.non_form_errors %}
    <span>{{ error }}</span> {% endfor %}
</p>
{% endif %}

<table class="listing page-permissions-listing">
    <col /> {% for i in formset.permission_types %}
    <col width="15%" /> {% endfor %}
    <col />
    <thead>
        <tr>
            <th>{% trans "Page" %}</th>
            {% for identifier, short_label, long_label in formset.permission_types %}
            <th title="{{ long_label }}">{{ short_label }}</th>
            {% endfor %}
            <th></th>
        </tr>
    </thead>
    <tbody id="id_{{ formset.prefix }}-FORMS">
        {% for form in formset.forms %}
        <tr id="inline_child_{{ form.prefix }}" {% if form.DELETE.value %} style="display: none;" {% endif %}>
            {% if form.non_field_errors %}
            <p class="error-message">
                {% for error in form.non_field_errors %}
                <span>{{ error|escape }}</span> {% endfor %}
            </p>
            {% endif %} {% include "shatailusers/groups/includes/page_permissions_form.html" with form=form only %}
        </tr>
        {% endfor %}
    </tbody>
</table>

<script type="text/django-form-template" id="id_{{ formset.prefix }}-EMPTY_FORM_TEMPLATE">
    {% escapescript %}
    <tr id="inline_child_{{ formset.empty_form.prefix }}">
        {% include "shatailusers/groups/includes/page_permissions_form.html" with form=formset.empty_form only %}
    </tr>
    {% endescapescript %}
</script>

<p class="add">
    <a class="button bicolor button--icon" id="id_{{ formset.prefix }}-ADD" value="Add">{% icon name="plus" wrapped=1 %}{% trans "Add a page permission" %}</a>
</p>