{% load i18n %} {% trans "Popular search terms" as pop_str %} {% include "shatailadmin/shared/header.html" with title=pop_str %}

<div class="nice-padding">
    <form class="query-search search-bar full-width" action="{% url 'shatailsearch_admin:queries_chooserresults' %}" method="GET" autocomplete="off" novalidate>
        <ul class="fields">
            {% for field in searchform %} {% include "shatailadmin/shared/field_as_li.html" with field=field %} {% endfor %}
            <li class="submit"><input type="submit" value="{% trans 'Search' %}" class="button" /></li>
        </ul>
    </form>

    <div id="query-results">
        {% include "shatailsearch/queries/chooser/results.html" %}
    </div>
</div>