{% load i18n shatailadmin_tags %} {% if documents %} {% if is_searching %}
<h2 role="alert">
    {% blocktrans trimmed count counter=documents|length %} There is {{ counter }} match {% plural %} There are {{ counter }} matches {% endblocktrans %}
</h2>

{% search_other %} {% endif %} {% include "shataildocs/documents/list.html" %} {% include "shatailadmin/shared/pagination_nav.html" with items=documents %} {% else %} {% if is_searching %}
<h2 role="alert">{% blocktrans trimmed %}Sorry, no documents match "<em>{{ query_string }}</em>"{% endblocktrans %}</h2>

{% search_other %} {% else %} {% url 'shataildocs:add_multiple' as shataildocs_add_document_url %} {% if current_collection %}
<p>{% blocktrans trimmed %}You haven't uploaded any documents in this collection. Why not <a href="{{ shataildocs_add_document_url }}">upload one now</a>?{% endblocktrans %}</p>
{% else %}
<p>{% blocktrans trimmed %}You haven't uploaded any documents. Why not <a href="{{ shataildocs_add_document_url }}">upload one now</a>?{% endblocktrans %}</p>
{% endif %} {% endif %} {% endif %}