# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['shatail',
 'shatail.actions',
 'shatail.admin',
 'shatail.admin.api',
 'shatail.admin.api.actions',
 'shatail.admin.forms',
 'shatail.admin.migrations',
 'shatail.admin.rich_text',
 'shatail.admin.rich_text.converters',
 'shatail.admin.rich_text.editors',
 'shatail.admin.rich_text.editors.draftail',
 'shatail.admin.templatetags',
 'shatail.admin.tests',
 'shatail.admin.tests.api',
 'shatail.admin.tests.pages',
 'shatail.admin.tests.pages.test_bulk_actions',
 'shatail.admin.tests.ui',
 'shatail.admin.ui',
 'shatail.admin.urls',
 'shatail.admin.views',
 'shatail.admin.views.bulk_action',
 'shatail.admin.views.generic',
 'shatail.admin.views.pages',
 'shatail.admin.views.pages.bulk_actions',
 'shatail.admin.views.reports',
 'shatail.admin.viewsets',
 'shatail.admin.widgets',
 'shatail.api',
 'shatail.api.v2',
 'shatail.api.v2.tests',
 'shatail.bin',
 'shatail.blocks',
 'shatail.contrib',
 'shatail.contrib.forms',
 'shatail.contrib.forms.migrations',
 'shatail.contrib.forms.tests',
 'shatail.contrib.frontend_cache',
 'shatail.contrib.legacy.richtext.tests',
 'shatail.contrib.legacy.sitemiddleware',
 'shatail.contrib.modeladmin',
 'shatail.contrib.modeladmin.helpers',
 'shatail.contrib.modeladmin.templatetags',
 'shatail.contrib.modeladmin.tests',
 'shatail.contrib.redirects',
 'shatail.contrib.redirects.management',
 'shatail.contrib.redirects.management.commands',
 'shatail.contrib.redirects.migrations',
 'shatail.contrib.redirects.tests',
 'shatail.contrib.routable_page',
 'shatail.contrib.routable_page.templatetags',
 'shatail.contrib.search_promotions',
 'shatail.contrib.search_promotions.migrations',
 'shatail.contrib.search_promotions.templatetags',
 'shatail.contrib.settings',
 'shatail.contrib.settings.templatetags',
 'shatail.contrib.settings.tests',
 'shatail.contrib.simple_translation',
 'shatail.contrib.simple_translation.migrations',
 'shatail.contrib.simple_translation.tests',
 'shatail.contrib.sitemaps',
 'shatail.contrib.styleguide',
 'shatail.contrib.table_block',
 'shatail.contrib.table_block.templatetags',
 'shatail.contrib.typed_table_block',
 'shatail.core',
 'shatail.core.blocks',
 'shatail.core.models',
 'shatail.core.permission_policies',
 'shatail.core.rich_text',
 'shatail.core.templatetags',
 'shatail.documents',
 'shatail.documents.api',
 'shatail.documents.api.admin',
 'shatail.documents.api.v2',
 'shatail.documents.migrations',
 'shatail.documents.rich_text',
 'shatail.documents.tests',
 'shatail.documents.tests.test_bulk_actions',
 'shatail.documents.views',
 'shatail.documents.views.bulk_actions',
 'shatail.embeds',
 'shatail.embeds.finders',
 'shatail.embeds.migrations',
 'shatail.embeds.rich_text',
 'shatail.embeds.templatetags',
 'shatail.embeds.tests',
 'shatail.embeds.views',
 'shatail.images',
 'shatail.images.api',
 'shatail.images.api.admin',
 'shatail.images.api.v2',
 'shatail.images.management',
 'shatail.images.management.commands',
 'shatail.images.migrations',
 'shatail.images.rich_text',
 'shatail.images.templatetags',
 'shatail.images.tests',
 'shatail.images.tests.test_bulk_actions',
 'shatail.images.views',
 'shatail.images.views.bulk_actions',
 'shatail.locales',
 'shatail.management',
 'shatail.management.commands',
 'shatail.migrations',
 'shatail.models',
 'shatail.permission_policies',
 'shatail.project_template',
 'shatail.project_template.home',
 'shatail.project_template.home.migrations',
 'shatail.project_template.project_name',
 'shatail.project_template.project_name.settings',
 'shatail.project_template.search',
 'shatail.rich_text',
 'shatail.search',
 'shatail.search.backends',
 'shatail.search.backends.database',
 'shatail.search.backends.database.mysql',
 'shatail.search.backends.database.postgres',
 'shatail.search.backends.database.sqlite',
 'shatail.search.management',
 'shatail.search.management.commands',
 'shatail.search.migrations',
 'shatail.search.tests',
 'shatail.search.urls',
 'shatail.search.views',
 'shatail.sites',
 'shatail.snippets',
 'shatail.snippets.templatetags',
 'shatail.snippets.views',
 'shatail.templatetags',
 'shatail.test',
 'shatail.test.customuser',
 'shatail.test.customuser.migrations',
 'shatail.test.demosite',
 'shatail.test.demosite.migrations',
 'shatail.test.emailuser',
 'shatail.test.emailuser.migrations',
 'shatail.test.i18n',
 'shatail.test.i18n.migrations',
 'shatail.test.modeladmintest',
 'shatail.test.modeladmintest.migrations',
 'shatail.test.routablepage',
 'shatail.test.routablepage.migrations',
 'shatail.test.search',
 'shatail.test.search.migrations',
 'shatail.test.snippets',
 'shatail.test.snippets.migrations',
 'shatail.test.testapp',
 'shatail.test.testapp.migrations',
 'shatail.test.utils',
 'shatail.tests',
 'shatail.tests.utils',
 'shatail.users',
 'shatail.users.migrations',
 'shatail.users.templatetags',
 'shatail.users.tests',
 'shatail.users.tests.test_bulk_actions',
 'shatail.users.urls',
 'shatail.users.views',
 'shatail.users.views.bulk_actions',
 'shatail.utils']

package_data = \
{'': ['*'],
 'shatail': ['locale/af/LC_MESSAGES/*',
             'locale/ar/LC_MESSAGES/*',
             'locale/az_AZ/LC_MESSAGES/*',
             'locale/be/LC_MESSAGES/*',
             'locale/bg/LC_MESSAGES/*',
             'locale/bn/LC_MESSAGES/*',
             'locale/ca/LC_MESSAGES/*',
             'locale/cs/LC_MESSAGES/*',
             'locale/cy/LC_MESSAGES/*',
             'locale/da/LC_MESSAGES/*',
             'locale/de/LC_MESSAGES/*',
             'locale/el/LC_MESSAGES/*',
             'locale/en/LC_MESSAGES/*',
             'locale/es/LC_MESSAGES/*',
             'locale/et/LC_MESSAGES/*',
             'locale/eu/LC_MESSAGES/*',
             'locale/fa/LC_MESSAGES/*',
             'locale/fi/LC_MESSAGES/*',
             'locale/fr/LC_MESSAGES/*',
             'locale/gl/LC_MESSAGES/*',
             'locale/he_IL/LC_MESSAGES/*',
             'locale/hr_HR/LC_MESSAGES/*',
             'locale/hu/LC_MESSAGES/*',
             'locale/id_ID/LC_MESSAGES/*',
             'locale/is_IS/LC_MESSAGES/*',
             'locale/it/LC_MESSAGES/*',
             'locale/ja/LC_MESSAGES/*',
             'locale/ka/LC_MESSAGES/*',
             'locale/ko/LC_MESSAGES/*',
             'locale/lt/LC_MESSAGES/*',
             'locale/lv/LC_MESSAGES/*',
             'locale/mi/LC_MESSAGES/*',
             'locale/mn/LC_MESSAGES/*',
             'locale/my/LC_MESSAGES/*',
             'locale/nb/LC_MESSAGES/*',
             'locale/nl/LC_MESSAGES/*',
             'locale/pl/LC_MESSAGES/*',
             'locale/pt_BR/LC_MESSAGES/*',
             'locale/pt_PT/LC_MESSAGES/*',
             'locale/ro/LC_MESSAGES/*',
             'locale/ru/LC_MESSAGES/*',
             'locale/sk_SK/LC_MESSAGES/*',
             'locale/sl/LC_MESSAGES/*',
             'locale/sv/LC_MESSAGES/*',
             'locale/tet/LC_MESSAGES/*',
             'locale/th/LC_MESSAGES/*',
             'locale/tr/LC_MESSAGES/*',
             'locale/tr_TR/LC_MESSAGES/*',
             'locale/uk/LC_MESSAGES/*',
             'locale/vi/LC_MESSAGES/*',
             'locale/zh/LC_MESSAGES/*',
             'locale/zh_Hans/LC_MESSAGES/*',
             'locale/zh_Hant/LC_MESSAGES/*',
             'templates/shatailcore/*',
             'templates/shatailcore/shared/*'],
 'shatail.admin': ['locale/af/LC_MESSAGES/*',
                   'locale/ar/LC_MESSAGES/*',
                   'locale/az_AZ/LC_MESSAGES/*',
                   'locale/be/LC_MESSAGES/*',
                   'locale/bg/LC_MESSAGES/*',
                   'locale/bn/LC_MESSAGES/*',
                   'locale/ca/LC_MESSAGES/*',
                   'locale/cs/LC_MESSAGES/*',
                   'locale/cy/LC_MESSAGES/*',
                   'locale/da/LC_MESSAGES/*',
                   'locale/de/LC_MESSAGES/*',
                   'locale/el/LC_MESSAGES/*',
                   'locale/en/LC_MESSAGES/*',
                   'locale/es/LC_MESSAGES/*',
                   'locale/et/LC_MESSAGES/*',
                   'locale/eu/LC_MESSAGES/*',
                   'locale/fa/LC_MESSAGES/*',
                   'locale/fi/LC_MESSAGES/*',
                   'locale/fr/LC_MESSAGES/*',
                   'locale/gl/LC_MESSAGES/*',
                   'locale/he_IL/LC_MESSAGES/*',
                   'locale/hr_HR/LC_MESSAGES/*',
                   'locale/ht/LC_MESSAGES/*',
                   'locale/hu/LC_MESSAGES/*',
                   'locale/hy/LC_MESSAGES/*',
                   'locale/id_ID/LC_MESSAGES/*',
                   'locale/is_IS/LC_MESSAGES/*',
                   'locale/it/LC_MESSAGES/*',
                   'locale/ja/LC_MESSAGES/*',
                   'locale/ka/LC_MESSAGES/*',
                   'locale/ko/LC_MESSAGES/*',
                   'locale/lt/LC_MESSAGES/*',
                   'locale/lv/LC_MESSAGES/*',
                   'locale/mi/LC_MESSAGES/*',
                   'locale/mn/LC_MESSAGES/*',
                   'locale/my/LC_MESSAGES/*',
                   'locale/nb/LC_MESSAGES/*',
                   'locale/nl/LC_MESSAGES/*',
                   'locale/pl/LC_MESSAGES/*',
                   'locale/pt_BR/LC_MESSAGES/*',
                   'locale/pt_PT/LC_MESSAGES/*',
                   'locale/ro/LC_MESSAGES/*',
                   'locale/ru/LC_MESSAGES/*',
                   'locale/sk_SK/LC_MESSAGES/*',
                   'locale/sl/LC_MESSAGES/*',
                   'locale/sv/LC_MESSAGES/*',
                   'locale/tet/LC_MESSAGES/*',
                   'locale/th/LC_MESSAGES/*',
                   'locale/tr/LC_MESSAGES/*',
                   'locale/tr_TR/LC_MESSAGES/*',
                   'locale/uk/LC_MESSAGES/*',
                   'locale/vi/LC_MESSAGES/*',
                   'locale/zh/LC_MESSAGES/*',
                   'locale/zh_Hans/LC_MESSAGES/*',
                   'locale/zh_Hant/LC_MESSAGES/*',
                   'static_src/*',
                   'static_src/shatailadmin/*',
                   'static_src/shatailadmin/css/*',
                   'static_src/shatailadmin/css/vendor/*',
                   'static_src/shatailadmin/css/vendor/jquery-ui/*',
                   'static_src/shatailadmin/css/vendor/jquery-ui/images/*',
                   'static_src/shatailadmin/fonts/*',
                   'static_src/shatailadmin/images/*',
                   'static_src/shatailadmin/images/icons/*',
                   'static_src/shatailadmin/js/*',
                   'static_src/shatailadmin/js/vendor/*',
                   'static_src/shatailadmin/scss/*',
                   'static_src/shatailadmin/scss/layouts/*',
                   'static_src/shatailadmin/scss/panels/*',
                   'templates/*',
                   'templates/shatailadmin/*',
                   'templates/shatailadmin/account/*',
                   'templates/shatailadmin/account/password_reset/*',
                   'templates/shatailadmin/account/settings_panels/*',
                   'templates/shatailadmin/bulk_actions/*',
                   'templates/shatailadmin/bulk_actions/confirmation/*',
                   'templates/shatailadmin/chooser/*',
                   'templates/shatailadmin/collection_privacy/*',
                   'templates/shatailadmin/collections/*',
                   'templates/shatailadmin/generic/*',
                   'templates/shatailadmin/generic/multiple_upload/*',
                   'templates/shatailadmin/home/*',
                   'templates/shatailadmin/icons/*',
                   'templates/shatailadmin/notifications/*',
                   'templates/shatailadmin/page_privacy/*',
                   'templates/shatailadmin/pages/*',
                   'templates/shatailadmin/pages/action_menu/*',
                   'templates/shatailadmin/pages/bulk_actions/*',
                   'templates/shatailadmin/pages/listing/*',
                   'templates/shatailadmin/pages/revisions/*',
                   'templates/shatailadmin/pages/side_panels/*',
                   'templates/shatailadmin/pages/side_panels/includes/*',
                   'templates/shatailadmin/pages/workflow_history/*',
                   'templates/shatailadmin/panels/*',
                   'templates/shatailadmin/panels/comments/*',
                   'templates/shatailadmin/permissions/*',
                   'templates/shatailadmin/permissions/includes/*',
                   'templates/shatailadmin/reports/*',
                   'templates/shatailadmin/reports/listing/*',
                   'templates/shatailadmin/shared/*',
                   'templates/shatailadmin/shared/headers/*',
                   'templates/shatailadmin/shared/tabs/*',
                   'templates/shatailadmin/tables/*',
                   'templates/shatailadmin/userbar/*',
                   'templates/shatailadmin/widgets/*',
                   'templates/shatailadmin/workflows/*',
                   'templates/shatailadmin/workflows/includes/*',
                   'templates/shatailadmin/workflows/task_chooser/*',
                   'templates/shatailadmin/workflows/task_chooser/includes/*',
                   'templates/shatailadmin/workflows/widgets/*'],
 'shatail.contrib': ['legacy/*',
                     'legacy/richtext/*',
                     'legacy/richtext/templates/*',
                     'legacy/richtext/templates/shatailcore/*',
                     'legacy/richtext/templates/shatailcore/shared/*'],
 'shatail.contrib.forms': ['locale/af/LC_MESSAGES/*',
                           'locale/ar/LC_MESSAGES/*',
                           'locale/az_AZ/LC_MESSAGES/*',
                           'locale/be/LC_MESSAGES/*',
                           'locale/bg/LC_MESSAGES/*',
                           'locale/bn/LC_MESSAGES/*',
                           'locale/ca/LC_MESSAGES/*',
                           'locale/cs/LC_MESSAGES/*',
                           'locale/cy/LC_MESSAGES/*',
                           'locale/da/LC_MESSAGES/*',
                           'locale/de/LC_MESSAGES/*',
                           'locale/el/LC_MESSAGES/*',
                           'locale/en/LC_MESSAGES/*',
                           'locale/es/LC_MESSAGES/*',
                           'locale/et/LC_MESSAGES/*',
                           'locale/eu/LC_MESSAGES/*',
                           'locale/fa/LC_MESSAGES/*',
                           'locale/fi/LC_MESSAGES/*',
                           'locale/fr/LC_MESSAGES/*',
                           'locale/gl/LC_MESSAGES/*',
                           'locale/he_IL/LC_MESSAGES/*',
                           'locale/hr_HR/LC_MESSAGES/*',
                           'locale/ht/LC_MESSAGES/*',
                           'locale/hu/LC_MESSAGES/*',
                           'locale/hy/LC_MESSAGES/*',
                           'locale/id_ID/LC_MESSAGES/*',
                           'locale/is_IS/LC_MESSAGES/*',
                           'locale/it/LC_MESSAGES/*',
                           'locale/ja/LC_MESSAGES/*',
                           'locale/ka/LC_MESSAGES/*',
                           'locale/ko/LC_MESSAGES/*',
                           'locale/lt/LC_MESSAGES/*',
                           'locale/lv/LC_MESSAGES/*',
                           'locale/mi/LC_MESSAGES/*',
                           'locale/mn/LC_MESSAGES/*',
                           'locale/my/LC_MESSAGES/*',
                           'locale/nb/LC_MESSAGES/*',
                           'locale/nl/LC_MESSAGES/*',
                           'locale/pl/LC_MESSAGES/*',
                           'locale/pt_BR/LC_MESSAGES/*',
                           'locale/pt_PT/LC_MESSAGES/*',
                           'locale/ro/LC_MESSAGES/*',
                           'locale/ru/LC_MESSAGES/*',
                           'locale/sk_SK/LC_MESSAGES/*',
                           'locale/sl/LC_MESSAGES/*',
                           'locale/sv/LC_MESSAGES/*',
                           'locale/tet/LC_MESSAGES/*',
                           'locale/th/LC_MESSAGES/*',
                           'locale/tr/LC_MESSAGES/*',
                           'locale/tr_TR/LC_MESSAGES/*',
                           'locale/uk/LC_MESSAGES/*',
                           'locale/vi/LC_MESSAGES/*',
                           'locale/zh/LC_MESSAGES/*',
                           'locale/zh_Hans/LC_MESSAGES/*',
                           'locale/zh_Hant/LC_MESSAGES/*',
                           'templates/*',
                           'templates/shatailforms/*',
                           'templates/shatailforms/panels/*'],
 'shatail.contrib.modeladmin': ['locale/af/LC_MESSAGES/*',
                                'locale/ar/LC_MESSAGES/*',
                                'locale/az_AZ/LC_MESSAGES/*',
                                'locale/be/LC_MESSAGES/*',
                                'locale/bg/LC_MESSAGES/*',
                                'locale/bn/LC_MESSAGES/*',
                                'locale/ca/LC_MESSAGES/*',
                                'locale/cs/LC_MESSAGES/*',
                                'locale/cy/LC_MESSAGES/*',
                                'locale/da/LC_MESSAGES/*',
                                'locale/de/LC_MESSAGES/*',
                                'locale/el/LC_MESSAGES/*',
                                'locale/en/LC_MESSAGES/*',
                                'locale/es/LC_MESSAGES/*',
                                'locale/et/LC_MESSAGES/*',
                                'locale/eu/LC_MESSAGES/*',
                                'locale/fa/LC_MESSAGES/*',
                                'locale/fi/LC_MESSAGES/*',
                                'locale/fr/LC_MESSAGES/*',
                                'locale/gl/LC_MESSAGES/*',
                                'locale/he_IL/LC_MESSAGES/*',
                                'locale/hr_HR/LC_MESSAGES/*',
                                'locale/ht/LC_MESSAGES/*',
                                'locale/hu/LC_MESSAGES/*',
                                'locale/id_ID/LC_MESSAGES/*',
                                'locale/is_IS/LC_MESSAGES/*',
                                'locale/it/LC_MESSAGES/*',
                                'locale/ja/LC_MESSAGES/*',
                                'locale/ka/LC_MESSAGES/*',
                                'locale/ko/LC_MESSAGES/*',
                                'locale/lt/LC_MESSAGES/*',
                                'locale/lv/LC_MESSAGES/*',
                                'locale/mi/LC_MESSAGES/*',
                                'locale/mn/LC_MESSAGES/*',
                                'locale/my/LC_MESSAGES/*',
                                'locale/nb/LC_MESSAGES/*',
                                'locale/nl/LC_MESSAGES/*',
                                'locale/pl/LC_MESSAGES/*',
                                'locale/pt_BR/LC_MESSAGES/*',
                                'locale/pt_PT/LC_MESSAGES/*',
                                'locale/ro/LC_MESSAGES/*',
                                'locale/ru/LC_MESSAGES/*',
                                'locale/sk_SK/LC_MESSAGES/*',
                                'locale/sl/LC_MESSAGES/*',
                                'locale/sr/LC_MESSAGES/*',
                                'locale/sv/LC_MESSAGES/*',
                                'locale/tet/LC_MESSAGES/*',
                                'locale/th/LC_MESSAGES/*',
                                'locale/tr/LC_MESSAGES/*',
                                'locale/tr_TR/LC_MESSAGES/*',
                                'locale/uk/LC_MESSAGES/*',
                                'locale/vi/LC_MESSAGES/*',
                                'locale/zh/LC_MESSAGES/*',
                                'locale/zh_Hans/LC_MESSAGES/*',
                                'locale/zh_Hant/LC_MESSAGES/*',
                                'static_src/*',
                                'static_src/shatailmodeladmin/*',
                                'static_src/shatailmodeladmin/js/*',
                                'static_src/shatailmodeladmin/scss/*',
                                'templates/*',
                                'templates/modeladmin/*',
                                'templates/modeladmin/includes/*'],
 'shatail.contrib.redirects': ['locale/af/LC_MESSAGES/*',
                               'locale/ar/LC_MESSAGES/*',
                               'locale/az_AZ/LC_MESSAGES/*',
                               'locale/be/LC_MESSAGES/*',
                               'locale/bg/LC_MESSAGES/*',
                               'locale/bn/LC_MESSAGES/*',
                               'locale/ca/LC_MESSAGES/*',
                               'locale/cs/LC_MESSAGES/*',
                               'locale/cy/LC_MESSAGES/*',
                               'locale/da/LC_MESSAGES/*',
                               'locale/de/LC_MESSAGES/*',
                               'locale/el/LC_MESSAGES/*',
                               'locale/en/LC_MESSAGES/*',
                               'locale/es/LC_MESSAGES/*',
                               'locale/et/LC_MESSAGES/*',
                               'locale/eu/LC_MESSAGES/*',
                               'locale/fa/LC_MESSAGES/*',
                               'locale/fi/LC_MESSAGES/*',
                               'locale/fr/LC_MESSAGES/*',
                               'locale/gl/LC_MESSAGES/*',
                               'locale/he_IL/LC_MESSAGES/*',
                               'locale/hr_HR/LC_MESSAGES/*',
                               'locale/ht/LC_MESSAGES/*',
                               'locale/hu/LC_MESSAGES/*',
                               'locale/hy/LC_MESSAGES/*',
                               'locale/id_ID/LC_MESSAGES/*',
                               'locale/is_IS/LC_MESSAGES/*',
                               'locale/it/LC_MESSAGES/*',
                               'locale/ja/LC_MESSAGES/*',
                               'locale/ka/LC_MESSAGES/*',
                               'locale/ko/LC_MESSAGES/*',
                               'locale/lt/LC_MESSAGES/*',
                               'locale/lv/LC_MESSAGES/*',
                               'locale/mi/LC_MESSAGES/*',
                               'locale/mn/LC_MESSAGES/*',
                               'locale/my/LC_MESSAGES/*',
                               'locale/nb/LC_MESSAGES/*',
                               'locale/nl/LC_MESSAGES/*',
                               'locale/pl/LC_MESSAGES/*',
                               'locale/pt_BR/LC_MESSAGES/*',
                               'locale/pt_PT/LC_MESSAGES/*',
                               'locale/ro/LC_MESSAGES/*',
                               'locale/ru/LC_MESSAGES/*',
                               'locale/sk_SK/LC_MESSAGES/*',
                               'locale/sl/LC_MESSAGES/*',
                               'locale/sr/LC_MESSAGES/*',
                               'locale/sv/LC_MESSAGES/*',
                               'locale/tet/LC_MESSAGES/*',
                               'locale/th/LC_MESSAGES/*',
                               'locale/tr/LC_MESSAGES/*',
                               'locale/tr_TR/LC_MESSAGES/*',
                               'locale/uk/LC_MESSAGES/*',
                               'locale/vi/LC_MESSAGES/*',
                               'locale/zh/LC_MESSAGES/*',
                               'locale/zh_Hans/LC_MESSAGES/*',
                               'locale/zh_Hant/LC_MESSAGES/*',
                               'static/*',
                               'static/shatailredirects/*',
                               'static/shatailredirects/css/*',
                               'templates/*',
                               'templates/shatailredirects/*',
                               'templates/shatailredirects/reports/*'],
 'shatail.contrib.redirects.tests': ['files/*'],
 'shatail.contrib.search_promotions': ['locale/af/LC_MESSAGES/*',
                                       'locale/ar/LC_MESSAGES/*',
                                       'locale/az_AZ/LC_MESSAGES/*',
                                       'locale/be/LC_MESSAGES/*',
                                       'locale/bg/LC_MESSAGES/*',
                                       'locale/bn/LC_MESSAGES/*',
                                       'locale/ca/LC_MESSAGES/*',
                                       'locale/cs/LC_MESSAGES/*',
                                       'locale/cy/LC_MESSAGES/*',
                                       'locale/da/LC_MESSAGES/*',
                                       'locale/de/LC_MESSAGES/*',
                                       'locale/el/LC_MESSAGES/*',
                                       'locale/en/LC_MESSAGES/*',
                                       'locale/es/LC_MESSAGES/*',
                                       'locale/et/LC_MESSAGES/*',
                                       'locale/eu/LC_MESSAGES/*',
                                       'locale/fa/LC_MESSAGES/*',
                                       'locale/fi/LC_MESSAGES/*',
                                       'locale/fr/LC_MESSAGES/*',
                                       'locale/gl/LC_MESSAGES/*',
                                       'locale/he_IL/LC_MESSAGES/*',
                                       'locale/hr_HR/LC_MESSAGES/*',
                                       'locale/ht/LC_MESSAGES/*',
                                       'locale/hu/LC_MESSAGES/*',
                                       'locale/id_ID/LC_MESSAGES/*',
                                       'locale/is_IS/LC_MESSAGES/*',
                                       'locale/it/LC_MESSAGES/*',
                                       'locale/ja/LC_MESSAGES/*',
                                       'locale/ka/LC_MESSAGES/*',
                                       'locale/ko/LC_MESSAGES/*',
                                       'locale/lt/LC_MESSAGES/*',
                                       'locale/lv/LC_MESSAGES/*',
                                       'locale/mi/LC_MESSAGES/*',
                                       'locale/mn/LC_MESSAGES/*',
                                       'locale/my/LC_MESSAGES/*',
                                       'locale/nb/LC_MESSAGES/*',
                                       'locale/nl/LC_MESSAGES/*',
                                       'locale/pl/LC_MESSAGES/*',
                                       'locale/pt_BR/LC_MESSAGES/*',
                                       'locale/pt_PT/LC_MESSAGES/*',
                                       'locale/ro/LC_MESSAGES/*',
                                       'locale/ru/LC_MESSAGES/*',
                                       'locale/sk_SK/LC_MESSAGES/*',
                                       'locale/sl/LC_MESSAGES/*',
                                       'locale/sr/LC_MESSAGES/*',
                                       'locale/sv/LC_MESSAGES/*',
                                       'locale/tet/LC_MESSAGES/*',
                                       'locale/th/LC_MESSAGES/*',
                                       'locale/tr/LC_MESSAGES/*',
                                       'locale/tr_TR/LC_MESSAGES/*',
                                       'locale/uk/LC_MESSAGES/*',
                                       'locale/vi/LC_MESSAGES/*',
                                       'locale/zh/LC_MESSAGES/*',
                                       'locale/zh_Hans/LC_MESSAGES/*',
                                       'locale/zh_Hant/LC_MESSAGES/*',
                                       'templates/*',
                                       'templates/shatailsearchpromotions/*',
                                       'templates/shatailsearchpromotions/includes/*'],
 'shatail.contrib.settings': ['locale/af/LC_MESSAGES/*',
                              'locale/ar/LC_MESSAGES/*',
                              'locale/az_AZ/LC_MESSAGES/*',
                              'locale/be/LC_MESSAGES/*',
                              'locale/bg/LC_MESSAGES/*',
                              'locale/bn/LC_MESSAGES/*',
                              'locale/ca/LC_MESSAGES/*',
                              'locale/cs/LC_MESSAGES/*',
                              'locale/cy/LC_MESSAGES/*',
                              'locale/da/LC_MESSAGES/*',
                              'locale/de/LC_MESSAGES/*',
                              'locale/el/LC_MESSAGES/*',
                              'locale/en/LC_MESSAGES/*',
                              'locale/es/LC_MESSAGES/*',
                              'locale/et/LC_MESSAGES/*',
                              'locale/fa/LC_MESSAGES/*',
                              'locale/fi/LC_MESSAGES/*',
                              'locale/fr/LC_MESSAGES/*',
                              'locale/gl/LC_MESSAGES/*',
                              'locale/he_IL/LC_MESSAGES/*',
                              'locale/hr_HR/LC_MESSAGES/*',
                              'locale/ht/LC_MESSAGES/*',
                              'locale/hu/LC_MESSAGES/*',
                              'locale/id_ID/LC_MESSAGES/*',
                              'locale/is_IS/LC_MESSAGES/*',
                              'locale/it/LC_MESSAGES/*',
                              'locale/ja/LC_MESSAGES/*',
                              'locale/ka/LC_MESSAGES/*',
                              'locale/ko/LC_MESSAGES/*',
                              'locale/lt/LC_MESSAGES/*',
                              'locale/lv/LC_MESSAGES/*',
                              'locale/mi/LC_MESSAGES/*',
                              'locale/mn/LC_MESSAGES/*',
                              'locale/my/LC_MESSAGES/*',
                              'locale/nb/LC_MESSAGES/*',
                              'locale/nl/LC_MESSAGES/*',
                              'locale/pl/LC_MESSAGES/*',
                              'locale/pt_BR/LC_MESSAGES/*',
                              'locale/pt_PT/LC_MESSAGES/*',
                              'locale/ro/LC_MESSAGES/*',
                              'locale/ru/LC_MESSAGES/*',
                              'locale/sk_SK/LC_MESSAGES/*',
                              'locale/sl/LC_MESSAGES/*',
                              'locale/sr/LC_MESSAGES/*',
                              'locale/sv/LC_MESSAGES/*',
                              'locale/tet/LC_MESSAGES/*',
                              'locale/th/LC_MESSAGES/*',
                              'locale/tr/LC_MESSAGES/*',
                              'locale/tr_TR/LC_MESSAGES/*',
                              'locale/uk/LC_MESSAGES/*',
                              'locale/vi/LC_MESSAGES/*',
                              'locale/zh/LC_MESSAGES/*',
                              'locale/zh_Hans/LC_MESSAGES/*',
                              'locale/zh_Hant/LC_MESSAGES/*',
                              'static_src/shatailsettings/js/*',
                              'templates/*',
                              'templates/shatailsettings/*'],
 'shatail.contrib.simple_translation': ['locale/ca/LC_MESSAGES/*',
                                        'locale/cs/LC_MESSAGES/*',
                                        'locale/cy/LC_MESSAGES/*',
                                        'locale/de/LC_MESSAGES/*',
                                        'locale/el/LC_MESSAGES/*',
                                        'locale/en/LC_MESSAGES/*',
                                        'locale/es/LC_MESSAGES/*',
                                        'locale/fi/LC_MESSAGES/*',
                                        'locale/fr/LC_MESSAGES/*',
                                        'locale/hr_HR/LC_MESSAGES/*',
                                        'locale/hu/LC_MESSAGES/*',
                                        'locale/is_IS/LC_MESSAGES/*',
                                        'locale/it/LC_MESSAGES/*',
                                        'locale/lt/LC_MESSAGES/*',
                                        'locale/mi/LC_MESSAGES/*',
                                        'locale/nl/LC_MESSAGES/*',
                                        'locale/pl/LC_MESSAGES/*',
                                        'locale/pt_BR/LC_MESSAGES/*',
                                        'locale/pt_PT/LC_MESSAGES/*',
                                        'locale/ro/LC_MESSAGES/*',
                                        'locale/ru/LC_MESSAGES/*',
                                        'locale/sl/LC_MESSAGES/*',
                                        'locale/sv/LC_MESSAGES/*',
                                        'locale/uk/LC_MESSAGES/*',
                                        'locale/vi/LC_MESSAGES/*',
                                        'locale/zh_Hans/LC_MESSAGES/*',
                                        'locale/zh_Hant/LC_MESSAGES/*',
                                        'templates/*',
                                        'templates/simple_translation/*',
                                        'templates/simple_translation/admin/*'],
 'shatail.contrib.styleguide': ['locale/af/LC_MESSAGES/*',
                                'locale/ar/LC_MESSAGES/*',
                                'locale/az_AZ/LC_MESSAGES/*',
                                'locale/be/LC_MESSAGES/*',
                                'locale/bg/LC_MESSAGES/*',
                                'locale/bn/LC_MESSAGES/*',
                                'locale/ca/LC_MESSAGES/*',
                                'locale/cs/LC_MESSAGES/*',
                                'locale/cy/LC_MESSAGES/*',
                                'locale/da/LC_MESSAGES/*',
                                'locale/de/LC_MESSAGES/*',
                                'locale/el/LC_MESSAGES/*',
                                'locale/en/LC_MESSAGES/*',
                                'locale/es/LC_MESSAGES/*',
                                'locale/et/LC_MESSAGES/*',
                                'locale/eu/LC_MESSAGES/*',
                                'locale/fa/LC_MESSAGES/*',
                                'locale/fi/LC_MESSAGES/*',
                                'locale/fr/LC_MESSAGES/*',
                                'locale/gl/LC_MESSAGES/*',
                                'locale/he_IL/LC_MESSAGES/*',
                                'locale/hr_HR/LC_MESSAGES/*',
                                'locale/ht/LC_MESSAGES/*',
                                'locale/hu/LC_MESSAGES/*',
                                'locale/id_ID/LC_MESSAGES/*',
                                'locale/is_IS/LC_MESSAGES/*',
                                'locale/it/LC_MESSAGES/*',
                                'locale/ja/LC_MESSAGES/*',
                                'locale/ka/LC_MESSAGES/*',
                                'locale/ko/LC_MESSAGES/*',
                                'locale/lt/LC_MESSAGES/*',
                                'locale/lv/LC_MESSAGES/*',
                                'locale/mi/LC_MESSAGES/*',
                                'locale/mn/LC_MESSAGES/*',
                                'locale/my/LC_MESSAGES/*',
                                'locale/nb/LC_MESSAGES/*',
                                'locale/nl/LC_MESSAGES/*',
                                'locale/pl/LC_MESSAGES/*',
                                'locale/pt_BR/LC_MESSAGES/*',
                                'locale/pt_PT/LC_MESSAGES/*',
                                'locale/ro/LC_MESSAGES/*',
                                'locale/ru/LC_MESSAGES/*',
                                'locale/sk_SK/LC_MESSAGES/*',
                                'locale/sl/LC_MESSAGES/*',
                                'locale/sv/LC_MESSAGES/*',
                                'locale/tet/LC_MESSAGES/*',
                                'locale/th/LC_MESSAGES/*',
                                'locale/tr/LC_MESSAGES/*',
                                'locale/tr_TR/LC_MESSAGES/*',
                                'locale/uk/LC_MESSAGES/*',
                                'locale/vi/LC_MESSAGES/*',
                                'locale/zh/LC_MESSAGES/*',
                                'locale/zh_Hans/LC_MESSAGES/*',
                                'locale/zh_Hant/LC_MESSAGES/*',
                                'static_src/shatailstyleguide/scss/*',
                                'templates/shatailstyleguide/*'],
 'shatail.contrib.table_block': ['locale/ar/LC_MESSAGES/*',
                                 'locale/be/LC_MESSAGES/*',
                                 'locale/ca/LC_MESSAGES/*',
                                 'locale/cs/LC_MESSAGES/*',
                                 'locale/cy/LC_MESSAGES/*',
                                 'locale/de/LC_MESSAGES/*',
                                 'locale/el/LC_MESSAGES/*',
                                 'locale/en/LC_MESSAGES/*',
                                 'locale/es/LC_MESSAGES/*',
                                 'locale/et/LC_MESSAGES/*',
                                 'locale/fa/LC_MESSAGES/*',
                                 'locale/fi/LC_MESSAGES/*',
                                 'locale/fr/LC_MESSAGES/*',
                                 'locale/gl/LC_MESSAGES/*',
                                 'locale/hr_HR/LC_MESSAGES/*',
                                 'locale/ht/LC_MESSAGES/*',
                                 'locale/hu/LC_MESSAGES/*',
                                 'locale/id_ID/LC_MESSAGES/*',
                                 'locale/is_IS/LC_MESSAGES/*',
                                 'locale/it/LC_MESSAGES/*',
                                 'locale/ja/LC_MESSAGES/*',
                                 'locale/ko/LC_MESSAGES/*',
                                 'locale/lt/LC_MESSAGES/*',
                                 'locale/lv/LC_MESSAGES/*',
                                 'locale/mi/LC_MESSAGES/*',
                                 'locale/mn/LC_MESSAGES/*',
                                 'locale/my/LC_MESSAGES/*',
                                 'locale/nb/LC_MESSAGES/*',
                                 'locale/nl/LC_MESSAGES/*',
                                 'locale/pl/LC_MESSAGES/*',
                                 'locale/pt_BR/LC_MESSAGES/*',
                                 'locale/pt_PT/LC_MESSAGES/*',
                                 'locale/ro/LC_MESSAGES/*',
                                 'locale/ru/LC_MESSAGES/*',
                                 'locale/sk_SK/LC_MESSAGES/*',
                                 'locale/sl/LC_MESSAGES/*',
                                 'locale/sv/LC_MESSAGES/*',
                                 'locale/tet/LC_MESSAGES/*',
                                 'locale/th/LC_MESSAGES/*',
                                 'locale/tr/LC_MESSAGES/*',
                                 'locale/tr_TR/LC_MESSAGES/*',
                                 'locale/uk/LC_MESSAGES/*',
                                 'locale/vi/LC_MESSAGES/*',
                                 'locale/zh_Hans/LC_MESSAGES/*',
                                 'locale/zh_Hant/LC_MESSAGES/*',
                                 'static/table_block/css/vendor/*',
                                 'static/table_block/js/*',
                                 'static/table_block/js/vendor/*',
                                 'templates/*',
                                 'templates/table_block/*',
                                 'templates/table_block/blocks/*'],
 'shatail.contrib.typed_table_block': ['locale/cy/LC_MESSAGES/*',
                                       'locale/de/LC_MESSAGES/*',
                                       'locale/el/LC_MESSAGES/*',
                                       'locale/en/LC_MESSAGES/*',
                                       'locale/es/LC_MESSAGES/*',
                                       'locale/fi/LC_MESSAGES/*',
                                       'locale/fr/LC_MESSAGES/*',
                                       'locale/gl/LC_MESSAGES/*',
                                       'locale/hu/LC_MESSAGES/*',
                                       'locale/is_IS/LC_MESSAGES/*',
                                       'locale/it/LC_MESSAGES/*',
                                       'locale/nl/LC_MESSAGES/*',
                                       'locale/pt_BR/LC_MESSAGES/*',
                                       'locale/pt_PT/LC_MESSAGES/*',
                                       'locale/ro/LC_MESSAGES/*',
                                       'locale/ru/LC_MESSAGES/*',
                                       'locale/sl/LC_MESSAGES/*',
                                       'locale/sv/LC_MESSAGES/*',
                                       'locale/uk/LC_MESSAGES/*',
                                       'locale/zh_Hans/LC_MESSAGES/*',
                                       'locale/zh_Hant/LC_MESSAGES/*',
                                       'static_src/typed_table_block/scss/*',
                                       'templates/typed_table_block/*'],
 'shatail.documents': ['locale/af/LC_MESSAGES/*',
                       'locale/ar/LC_MESSAGES/*',
                       'locale/az_AZ/LC_MESSAGES/*',
                       'locale/be/LC_MESSAGES/*',
                       'locale/bg/LC_MESSAGES/*',
                       'locale/bn/LC_MESSAGES/*',
                       'locale/ca/LC_MESSAGES/*',
                       'locale/cs/LC_MESSAGES/*',
                       'locale/cy/LC_MESSAGES/*',
                       'locale/da/LC_MESSAGES/*',
                       'locale/de/LC_MESSAGES/*',
                       'locale/el/LC_MESSAGES/*',
                       'locale/en/LC_MESSAGES/*',
                       'locale/es/LC_MESSAGES/*',
                       'locale/et/LC_MESSAGES/*',
                       'locale/eu/LC_MESSAGES/*',
                       'locale/fa/LC_MESSAGES/*',
                       'locale/fi/LC_MESSAGES/*',
                       'locale/fr/LC_MESSAGES/*',
                       'locale/gl/LC_MESSAGES/*',
                       'locale/he_IL/LC_MESSAGES/*',
                       'locale/hr_HR/LC_MESSAGES/*',
                       'locale/ht/LC_MESSAGES/*',
                       'locale/hu/LC_MESSAGES/*',
                       'locale/id_ID/LC_MESSAGES/*',
                       'locale/is_IS/LC_MESSAGES/*',
                       'locale/it/LC_MESSAGES/*',
                       'locale/ja/LC_MESSAGES/*',
                       'locale/ka/LC_MESSAGES/*',
                       'locale/ko/LC_MESSAGES/*',
                       'locale/lt/LC_MESSAGES/*',
                       'locale/lv/LC_MESSAGES/*',
                       'locale/mi/LC_MESSAGES/*',
                       'locale/mn/LC_MESSAGES/*',
                       'locale/my/LC_MESSAGES/*',
                       'locale/nb/LC_MESSAGES/*',
                       'locale/nl/LC_MESSAGES/*',
                       'locale/pl/LC_MESSAGES/*',
                       'locale/pt_BR/LC_MESSAGES/*',
                       'locale/pt_PT/LC_MESSAGES/*',
                       'locale/ro/LC_MESSAGES/*',
                       'locale/ru/LC_MESSAGES/*',
                       'locale/sk_SK/LC_MESSAGES/*',
                       'locale/sl/LC_MESSAGES/*',
                       'locale/sr/LC_MESSAGES/*',
                       'locale/sv/LC_MESSAGES/*',
                       'locale/tet/LC_MESSAGES/*',
                       'locale/th/LC_MESSAGES/*',
                       'locale/tr/LC_MESSAGES/*',
                       'locale/tr_TR/LC_MESSAGES/*',
                       'locale/uk/LC_MESSAGES/*',
                       'locale/vi/LC_MESSAGES/*',
                       'locale/zh/LC_MESSAGES/*',
                       'locale/zh_Hans/LC_MESSAGES/*',
                       'locale/zh_Hant/LC_MESSAGES/*',
                       'static_src/*',
                       'static_src/shataildocs/*',
                       'static_src/shataildocs/js/*',
                       'static_src/shataildocs/scss/*',
                       'templates/*',
                       'templates/shataildocs/*',
                       'templates/shataildocs/bulk_actions/*',
                       'templates/shataildocs/chooser/*',
                       'templates/shataildocs/documents/*',
                       'templates/shataildocs/homepage/*',
                       'templates/shataildocs/multiple/*',
                       'templates/shataildocs/permissions/*',
                       'templates/shataildocs/permissions/includes/*',
                       'templates/shataildocs/tables/*',
                       'templates/shataildocs/widgets/*'],
 'shatail.embeds': ['locale/ar/LC_MESSAGES/*',
                    'locale/az_AZ/LC_MESSAGES/*',
                    'locale/be/LC_MESSAGES/*',
                    'locale/bg/LC_MESSAGES/*',
                    'locale/bn/LC_MESSAGES/*',
                    'locale/ca/LC_MESSAGES/*',
                    'locale/cs/LC_MESSAGES/*',
                    'locale/cy/LC_MESSAGES/*',
                    'locale/da/LC_MESSAGES/*',
                    'locale/de/LC_MESSAGES/*',
                    'locale/el/LC_MESSAGES/*',
                    'locale/en/LC_MESSAGES/*',
                    'locale/es/LC_MESSAGES/*',
                    'locale/et/LC_MESSAGES/*',
                    'locale/fa/LC_MESSAGES/*',
                    'locale/fi/LC_MESSAGES/*',
                    'locale/fr/LC_MESSAGES/*',
                    'locale/gl/LC_MESSAGES/*',
                    'locale/he_IL/LC_MESSAGES/*',
                    'locale/hr_HR/LC_MESSAGES/*',
                    'locale/ht/LC_MESSAGES/*',
                    'locale/hu/LC_MESSAGES/*',
                    'locale/id_ID/LC_MESSAGES/*',
                    'locale/is_IS/LC_MESSAGES/*',
                    'locale/it/LC_MESSAGES/*',
                    'locale/ja/LC_MESSAGES/*',
                    'locale/ko/LC_MESSAGES/*',
                    'locale/lt/LC_MESSAGES/*',
                    'locale/lv/LC_MESSAGES/*',
                    'locale/mi/LC_MESSAGES/*',
                    'locale/mn/LC_MESSAGES/*',
                    'locale/my/LC_MESSAGES/*',
                    'locale/nb/LC_MESSAGES/*',
                    'locale/nl/LC_MESSAGES/*',
                    'locale/pl/LC_MESSAGES/*',
                    'locale/pt_BR/LC_MESSAGES/*',
                    'locale/pt_PT/LC_MESSAGES/*',
                    'locale/ro/LC_MESSAGES/*',
                    'locale/ru/LC_MESSAGES/*',
                    'locale/sk_SK/LC_MESSAGES/*',
                    'locale/sl/LC_MESSAGES/*',
                    'locale/sv/LC_MESSAGES/*',
                    'locale/tet/LC_MESSAGES/*',
                    'locale/th/LC_MESSAGES/*',
                    'locale/tr/LC_MESSAGES/*',
                    'locale/tr_TR/LC_MESSAGES/*',
                    'locale/uk/LC_MESSAGES/*',
                    'locale/vi/LC_MESSAGES/*',
                    'locale/zh/LC_MESSAGES/*',
                    'locale/zh_Hans/LC_MESSAGES/*',
                    'locale/zh_Hant/LC_MESSAGES/*',
                    'static_src/shatailembeds/js/*',
                    'templates/shatailembeds/*',
                    'templates/shatailembeds/chooser/*'],
 'shatail.images': ['check_files/*',
                    'locale/af/LC_MESSAGES/*',
                    'locale/ar/LC_MESSAGES/*',
                    'locale/az_AZ/LC_MESSAGES/*',
                    'locale/be/LC_MESSAGES/*',
                    'locale/bg/LC_MESSAGES/*',
                    'locale/bn/LC_MESSAGES/*',
                    'locale/ca/LC_MESSAGES/*',
                    'locale/cs/LC_MESSAGES/*',
                    'locale/cy/LC_MESSAGES/*',
                    'locale/da/LC_MESSAGES/*',
                    'locale/de/LC_MESSAGES/*',
                    'locale/el/LC_MESSAGES/*',
                    'locale/en/LC_MESSAGES/*',
                    'locale/es/LC_MESSAGES/*',
                    'locale/et/LC_MESSAGES/*',
                    'locale/eu/LC_MESSAGES/*',
                    'locale/fa/LC_MESSAGES/*',
                    'locale/fi/LC_MESSAGES/*',
                    'locale/fr/LC_MESSAGES/*',
                    'locale/gl/LC_MESSAGES/*',
                    'locale/he_IL/LC_MESSAGES/*',
                    'locale/hr_HR/LC_MESSAGES/*',
                    'locale/ht/LC_MESSAGES/*',
                    'locale/hu/LC_MESSAGES/*',
                    'locale/hy/LC_MESSAGES/*',
                    'locale/id_ID/LC_MESSAGES/*',
                    'locale/is_IS/LC_MESSAGES/*',
                    'locale/it/LC_MESSAGES/*',
                    'locale/ja/LC_MESSAGES/*',
                    'locale/ka/LC_MESSAGES/*',
                    'locale/ko/LC_MESSAGES/*',
                    'locale/lt/LC_MESSAGES/*',
                    'locale/lv/LC_MESSAGES/*',
                    'locale/mi/LC_MESSAGES/*',
                    'locale/mn/LC_MESSAGES/*',
                    'locale/my/LC_MESSAGES/*',
                    'locale/nb/LC_MESSAGES/*',
                    'locale/nl/LC_MESSAGES/*',
                    'locale/pl/LC_MESSAGES/*',
                    'locale/pt_BR/LC_MESSAGES/*',
                    'locale/pt_PT/LC_MESSAGES/*',
                    'locale/ro/LC_MESSAGES/*',
                    'locale/ru/LC_MESSAGES/*',
                    'locale/sk_SK/LC_MESSAGES/*',
                    'locale/sl/LC_MESSAGES/*',
                    'locale/sv/LC_MESSAGES/*',
                    'locale/tet/LC_MESSAGES/*',
                    'locale/th/LC_MESSAGES/*',
                    'locale/tr/LC_MESSAGES/*',
                    'locale/tr_TR/LC_MESSAGES/*',
                    'locale/uk/LC_MESSAGES/*',
                    'locale/vi/LC_MESSAGES/*',
                    'locale/zh/LC_MESSAGES/*',
                    'locale/zh_Hans/LC_MESSAGES/*',
                    'locale/zh_Hant/LC_MESSAGES/*',
                    'static_src/shatailimages/css/vendor/*',
                    'static_src/shatailimages/js/*',
                    'static_src/shatailimages/js/vendor/*',
                    'static_src/shatailimages/scss/*',
                    'templates/shatailimages/bulk_actions/*',
                    'templates/shatailimages/chooser/*',
                    'templates/shatailimages/homepage/*',
                    'templates/shatailimages/images/*',
                    'templates/shatailimages/multiple/*',
                    'templates/shatailimages/permissions/includes/*',
                    'templates/shatailimages/widgets/*'],
 'shatail.images.tests': ['image_files/*'],
 'shatail.locales': ['locale/ar/LC_MESSAGES/*',
                     'locale/be/LC_MESSAGES/*',
                     'locale/bg/LC_MESSAGES/*',
                     'locale/ca/LC_MESSAGES/*',
                     'locale/cs/LC_MESSAGES/*',
                     'locale/cy/LC_MESSAGES/*',
                     'locale/da/LC_MESSAGES/*',
                     'locale/de/LC_MESSAGES/*',
                     'locale/el/LC_MESSAGES/*',
                     'locale/en/LC_MESSAGES/*',
                     'locale/es/LC_MESSAGES/*',
                     'locale/et/LC_MESSAGES/*',
                     'locale/fa/LC_MESSAGES/*',
                     'locale/fi/LC_MESSAGES/*',
                     'locale/fr/LC_MESSAGES/*',
                     'locale/gl/LC_MESSAGES/*',
                     'locale/he_IL/LC_MESSAGES/*',
                     'locale/hr_HR/LC_MESSAGES/*',
                     'locale/hu/LC_MESSAGES/*',
                     'locale/id_ID/LC_MESSAGES/*',
                     'locale/is_IS/LC_MESSAGES/*',
                     'locale/it/LC_MESSAGES/*',
                     'locale/ja/LC_MESSAGES/*',
                     'locale/ko/LC_MESSAGES/*',
                     'locale/lt/LC_MESSAGES/*',
                     'locale/lv/LC_MESSAGES/*',
                     'locale/mi/LC_MESSAGES/*',
                     'locale/mn/LC_MESSAGES/*',
                     'locale/my/LC_MESSAGES/*',
                     'locale/nb/LC_MESSAGES/*',
                     'locale/nl/LC_MESSAGES/*',
                     'locale/pl/LC_MESSAGES/*',
                     'locale/pt_BR/LC_MESSAGES/*',
                     'locale/pt_PT/LC_MESSAGES/*',
                     'locale/ro/LC_MESSAGES/*',
                     'locale/ru/LC_MESSAGES/*',
                     'locale/sk_SK/LC_MESSAGES/*',
                     'locale/sl/LC_MESSAGES/*',
                     'locale/sv/LC_MESSAGES/*',
                     'locale/tet/LC_MESSAGES/*',
                     'locale/th/LC_MESSAGES/*',
                     'locale/tr/LC_MESSAGES/*',
                     'locale/tr_TR/LC_MESSAGES/*',
                     'locale/uk/LC_MESSAGES/*',
                     'locale/vi/LC_MESSAGES/*',
                     'locale/zh/LC_MESSAGES/*',
                     'locale/zh_Hans/LC_MESSAGES/*',
                     'locale/zh_Hant/LC_MESSAGES/*',
                     'templates/shataillocales/*'],
 'shatail.project_template.home': ['static/*',
                                   'static/css/*',
                                   'templates/*',
                                   'templates/home/*'],
 'shatail.project_template.project_name': ['static/css/*',
                                           'static/js/*',
                                           'templates/*'],
 'shatail.project_template.search': ['templates/*', 'templates/search/*'],
 'shatail.search': ['locale/af/LC_MESSAGES/*',
                    'locale/ar/LC_MESSAGES/*',
                    'locale/be/LC_MESSAGES/*',
                    'locale/bg/LC_MESSAGES/*',
                    'locale/bn/LC_MESSAGES/*',
                    'locale/ca/LC_MESSAGES/*',
                    'locale/cs/LC_MESSAGES/*',
                    'locale/cy/LC_MESSAGES/*',
                    'locale/da/LC_MESSAGES/*',
                    'locale/de/LC_MESSAGES/*',
                    'locale/el/LC_MESSAGES/*',
                    'locale/en/LC_MESSAGES/*',
                    'locale/es/LC_MESSAGES/*',
                    'locale/et/LC_MESSAGES/*',
                    'locale/eu/LC_MESSAGES/*',
                    'locale/fa/LC_MESSAGES/*',
                    'locale/fi/LC_MESSAGES/*',
                    'locale/fr/LC_MESSAGES/*',
                    'locale/gl/LC_MESSAGES/*',
                    'locale/he_IL/LC_MESSAGES/*',
                    'locale/hr_HR/LC_MESSAGES/*',
                    'locale/ht/LC_MESSAGES/*',
                    'locale/hu/LC_MESSAGES/*',
                    'locale/id_ID/LC_MESSAGES/*',
                    'locale/is_IS/LC_MESSAGES/*',
                    'locale/it/LC_MESSAGES/*',
                    'locale/ja/LC_MESSAGES/*',
                    'locale/ka/LC_MESSAGES/*',
                    'locale/ko/LC_MESSAGES/*',
                    'locale/lt/LC_MESSAGES/*',
                    'locale/lv/LC_MESSAGES/*',
                    'locale/mi/LC_MESSAGES/*',
                    'locale/mn/LC_MESSAGES/*',
                    'locale/my/LC_MESSAGES/*',
                    'locale/nb/LC_MESSAGES/*',
                    'locale/nl/LC_MESSAGES/*',
                    'locale/pl/LC_MESSAGES/*',
                    'locale/pt_BR/LC_MESSAGES/*',
                    'locale/pt_PT/LC_MESSAGES/*',
                    'locale/ro/LC_MESSAGES/*',
                    'locale/ru/LC_MESSAGES/*',
                    'locale/sk_SK/LC_MESSAGES/*',
                    'locale/sl/LC_MESSAGES/*',
                    'locale/sv/LC_MESSAGES/*',
                    'locale/tet/LC_MESSAGES/*',
                    'locale/th/LC_MESSAGES/*',
                    'locale/tr/LC_MESSAGES/*',
                    'locale/tr_TR/LC_MESSAGES/*',
                    'locale/uk/LC_MESSAGES/*',
                    'locale/vi/LC_MESSAGES/*',
                    'locale/zh/LC_MESSAGES/*',
                    'locale/zh_Hans/LC_MESSAGES/*',
                    'locale/zh_Hant/LC_MESSAGES/*',
                    'static_src/shatailsearch/js/*',
                    'templates/shatailsearch/*',
                    'templates/shatailsearch/queries/*',
                    'templates/shatailsearch/queries/chooser/*'],
 'shatail.sites': ['locale/ar/LC_MESSAGES/*',
                   'locale/be/LC_MESSAGES/*',
                   'locale/bn/LC_MESSAGES/*',
                   'locale/ca/LC_MESSAGES/*',
                   'locale/cs/LC_MESSAGES/*',
                   'locale/cy/LC_MESSAGES/*',
                   'locale/da/LC_MESSAGES/*',
                   'locale/de/LC_MESSAGES/*',
                   'locale/el/LC_MESSAGES/*',
                   'locale/en/LC_MESSAGES/*',
                   'locale/es/LC_MESSAGES/*',
                   'locale/et/LC_MESSAGES/*',
                   'locale/fa/LC_MESSAGES/*',
                   'locale/fi/LC_MESSAGES/*',
                   'locale/fr/LC_MESSAGES/*',
                   'locale/gl/LC_MESSAGES/*',
                   'locale/he_IL/LC_MESSAGES/*',
                   'locale/hr_HR/LC_MESSAGES/*',
                   'locale/ht/LC_MESSAGES/*',
                   'locale/hu/LC_MESSAGES/*',
                   'locale/id_ID/LC_MESSAGES/*',
                   'locale/is_IS/LC_MESSAGES/*',
                   'locale/it/LC_MESSAGES/*',
                   'locale/ja/LC_MESSAGES/*',
                   'locale/ka/LC_MESSAGES/*',
                   'locale/ko/LC_MESSAGES/*',
                   'locale/lt/LC_MESSAGES/*',
                   'locale/lv/LC_MESSAGES/*',
                   'locale/mi/LC_MESSAGES/*',
                   'locale/mn/LC_MESSAGES/*',
                   'locale/my/LC_MESSAGES/*',
                   'locale/nb/LC_MESSAGES/*',
                   'locale/nl/LC_MESSAGES/*',
                   'locale/pl/LC_MESSAGES/*',
                   'locale/pt_BR/LC_MESSAGES/*',
                   'locale/pt_PT/LC_MESSAGES/*',
                   'locale/ro/LC_MESSAGES/*',
                   'locale/ru/LC_MESSAGES/*',
                   'locale/sk_SK/LC_MESSAGES/*',
                   'locale/sl/LC_MESSAGES/*',
                   'locale/sr/LC_MESSAGES/*',
                   'locale/sv/LC_MESSAGES/*',
                   'locale/tet/LC_MESSAGES/*',
                   'locale/th/LC_MESSAGES/*',
                   'locale/tr/LC_MESSAGES/*',
                   'locale/tr_TR/LC_MESSAGES/*',
                   'locale/uk/LC_MESSAGES/*',
                   'locale/vi/LC_MESSAGES/*',
                   'locale/zh_Hans/LC_MESSAGES/*',
                   'locale/zh_Hant/LC_MESSAGES/*',
                   'templates/*',
                   'templates/shatailsites/*'],
 'shatail.snippets': ['locale/af/LC_MESSAGES/*',
                      'locale/ar/LC_MESSAGES/*',
                      'locale/az_AZ/LC_MESSAGES/*',
                      'locale/be/LC_MESSAGES/*',
                      'locale/bg/LC_MESSAGES/*',
                      'locale/bn/LC_MESSAGES/*',
                      'locale/ca/LC_MESSAGES/*',
                      'locale/cs/LC_MESSAGES/*',
                      'locale/cy/LC_MESSAGES/*',
                      'locale/da/LC_MESSAGES/*',
                      'locale/de/LC_MESSAGES/*',
                      'locale/el/LC_MESSAGES/*',
                      'locale/en/LC_MESSAGES/*',
                      'locale/es/LC_MESSAGES/*',
                      'locale/et/LC_MESSAGES/*',
                      'locale/eu/LC_MESSAGES/*',
                      'locale/fa/LC_MESSAGES/*',
                      'locale/fi/LC_MESSAGES/*',
                      'locale/fr/LC_MESSAGES/*',
                      'locale/gl/LC_MESSAGES/*',
                      'locale/he_IL/LC_MESSAGES/*',
                      'locale/hr_HR/LC_MESSAGES/*',
                      'locale/ht/LC_MESSAGES/*',
                      'locale/hu/LC_MESSAGES/*',
                      'locale/id_ID/LC_MESSAGES/*',
                      'locale/is_IS/LC_MESSAGES/*',
                      'locale/it/LC_MESSAGES/*',
                      'locale/ja/LC_MESSAGES/*',
                      'locale/ka/LC_MESSAGES/*',
                      'locale/ko/LC_MESSAGES/*',
                      'locale/lt/LC_MESSAGES/*',
                      'locale/lv/LC_MESSAGES/*',
                      'locale/mi/LC_MESSAGES/*',
                      'locale/mn/LC_MESSAGES/*',
                      'locale/my/LC_MESSAGES/*',
                      'locale/nb/LC_MESSAGES/*',
                      'locale/nl/LC_MESSAGES/*',
                      'locale/pl/LC_MESSAGES/*',
                      'locale/pt_BR/LC_MESSAGES/*',
                      'locale/pt_PT/LC_MESSAGES/*',
                      'locale/ro/LC_MESSAGES/*',
                      'locale/ru/LC_MESSAGES/*',
                      'locale/sk_SK/LC_MESSAGES/*',
                      'locale/sl/LC_MESSAGES/*',
                      'locale/sr/LC_MESSAGES/*',
                      'locale/sv/LC_MESSAGES/*',
                      'locale/tet/LC_MESSAGES/*',
                      'locale/th/LC_MESSAGES/*',
                      'locale/tr/LC_MESSAGES/*',
                      'locale/tr_TR/LC_MESSAGES/*',
                      'locale/uk/LC_MESSAGES/*',
                      'locale/vi/LC_MESSAGES/*',
                      'locale/zh/LC_MESSAGES/*',
                      'locale/zh_Hans/LC_MESSAGES/*',
                      'locale/zh_Hant/LC_MESSAGES/*',
                      'static_src/shatailsnippets/js/*',
                      'templates/shatailsnippets/chooser/*',
                      'templates/shatailsnippets/snippets/*',
                      'templates/shatailsnippets/snippets/action_menu/*',
                      'templates/shatailsnippets/widgets/*'],
 'shatail.test.customuser': ['fixtures/*'],
 'shatail.test.demosite': ['fixtures/*'],
 'shatail.test.emailuser': ['fixtures/*'],
 'shatail.test.modeladmintest': ['fixtures/*'],
 'shatail.test.routablepage': ['templates/*', 'templates/routablepagetests/*'],
 'shatail.test.search': ['fixtures/*'],
 'shatail.test.testapp': ['fixtures/*',
                          'jinja2_templates/*',
                          'jinja2_templates/tests/jinja2/*',
                          'templates/tests/*',
                          'templates/tests/block_forms/*',
                          'templates/tests/blocks/*',
                          'templates/tests/includes/*'],
 'shatail.users': ['locale/af/LC_MESSAGES/*',
                   'locale/ar/LC_MESSAGES/*',
                   'locale/az_AZ/LC_MESSAGES/*',
                   'locale/be/LC_MESSAGES/*',
                   'locale/bg/LC_MESSAGES/*',
                   'locale/bn/LC_MESSAGES/*',
                   'locale/ca/LC_MESSAGES/*',
                   'locale/cs/LC_MESSAGES/*',
                   'locale/cy/LC_MESSAGES/*',
                   'locale/da/LC_MESSAGES/*',
                   'locale/de/LC_MESSAGES/*',
                   'locale/el/LC_MESSAGES/*',
                   'locale/en/LC_MESSAGES/*',
                   'locale/es/LC_MESSAGES/*',
                   'locale/et/LC_MESSAGES/*',
                   'locale/eu/LC_MESSAGES/*',
                   'locale/fa/LC_MESSAGES/*',
                   'locale/fi/LC_MESSAGES/*',
                   'locale/fr/LC_MESSAGES/*',
                   'locale/gl/LC_MESSAGES/*',
                   'locale/he_IL/LC_MESSAGES/*',
                   'locale/hr_HR/LC_MESSAGES/*',
                   'locale/ht/LC_MESSAGES/*',
                   'locale/hu/LC_MESSAGES/*',
                   'locale/hy/LC_MESSAGES/*',
                   'locale/id_ID/LC_MESSAGES/*',
                   'locale/is_IS/LC_MESSAGES/*',
                   'locale/it/LC_MESSAGES/*',
                   'locale/ja/LC_MESSAGES/*',
                   'locale/ka/LC_MESSAGES/*',
                   'locale/ko/LC_MESSAGES/*',
                   'locale/lt/LC_MESSAGES/*',
                   'locale/lv/LC_MESSAGES/*',
                   'locale/mi/LC_MESSAGES/*',
                   'locale/mn/LC_MESSAGES/*',
                   'locale/my/LC_MESSAGES/*',
                   'locale/nb/LC_MESSAGES/*',
                   'locale/nl/LC_MESSAGES/*',
                   'locale/pl/LC_MESSAGES/*',
                   'locale/pt_BR/LC_MESSAGES/*',
                   'locale/pt_PT/LC_MESSAGES/*',
                   'locale/ro/LC_MESSAGES/*',
                   'locale/ru/LC_MESSAGES/*',
                   'locale/sk_SK/LC_MESSAGES/*',
                   'locale/sl/LC_MESSAGES/*',
                   'locale/sr/LC_MESSAGES/*',
                   'locale/sv/LC_MESSAGES/*',
                   'locale/tet/LC_MESSAGES/*',
                   'locale/th/LC_MESSAGES/*',
                   'locale/tr/LC_MESSAGES/*',
                   'locale/tr_TR/LC_MESSAGES/*',
                   'locale/uk/LC_MESSAGES/*',
                   'locale/vi/LC_MESSAGES/*',
                   'locale/zh/LC_MESSAGES/*',
                   'locale/zh_Hans/LC_MESSAGES/*',
                   'locale/zh_Hant/LC_MESSAGES/*',
                   'static_src/shatailusers/js/*',
                   'static_src/shatailusers/scss/*',
                   'templates/shatailusers/bulk_actions/*',
                   'templates/shatailusers/groups/*',
                   'templates/shatailusers/groups/includes/*',
                   'templates/shatailusers/users/*']}

install_requires = \
['importlib_metadata>=3.4.0,<4.0.0']

setup_kwargs = {
    'name': 'shatail',
    'version': '0.1.0',
    'description': '根据Wagtail修改的Django CMS 系统。',
    'long_description': '# Shatail\n\n\n[![PyPI version](https://badge.fury.io/py/shatail.svg)](https://badge.fury.io/py/shatail)\n![versions](https://img.shields.io/pypi/pyversions/shatail.svg)\n[![GitHub license](https://img.shields.io/github/license/mgancita/shatail.svg)](https://github.com/mgancita/shatail/blob/main/LICENSE)\n\n\n[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)\n\n\n根据Wagtail修改的Django CMS 系统。\n\n\n- 开源许可: BSD-3-Clause\n- 文档: https://llango.github.io/shatail.\n\n\n## 特征\n\n* TODO\n\n## 制作\n\n\n该包使用 [Cookiecutter](https://github.com/audreyr/cookiecutter) 和 [`llango/cookiecutter-mkdoc-shapackage`](https://github.com/llango/cookiecutter-mkdoc-shapackage/) 项目模版创建。\n',
    'author': 'Rontomai',
    'author_email': 'rontomai@gmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/llango/shatail',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.7,<4.0',
}


setup(**setup_kwargs)
