{% extends "shatailadmin/base.html" %} {% load i18n shatailadmin_tags %} {% block titletag %}{% blocktrans trimmed with snippet_type_name=model_opts.verbose_name %}New {{ snippet_type_name }}{% endblocktrans %}{% endblock %} {% block content %} {% trans
"New" as new_str %} {% include "shatailadmin/shared/header_with_locale_selector.html" with title=new_str subtitle=model_opts.verbose_name icon="snippet" merged=1 locale=locale translations=translations only %}

<form action="{{ action_url }}" method="POST" novalidate{% if form.is_multipart %} enctype="multipart/form-data" {% endif %}>
    {% csrf_token %} {{ edit_handler.render_form_content }}

    <footer class="footer">
        <nav aria-label="{% trans 'Actions' %}">
            <ul>
                <li class="actions actions--primary footer__container">
                    <div class="dropdown dropup dropdown-button match-width">
                        {{ action_menu.render_html }}
                    </div>
                </li>
            </ul>
        </nav>
    </footer>
</form>

{% endblock %} {% block extra_css %} {{ block.super }} {% include "shatailadmin/pages/_editor_css.html" %} {{ media.css }} {% endblock %} {% block extra_js %} {{ block.super }} {% include "shatailadmin/pages/_editor_js.html" %} {{ media.js }}

<script>
    // Set shatailConfig.ACTIVE_CONTENT_LOCALE if this is a translated page
    // This value may be used by JS widgets on the form
    { %
        if locale %
    }
    window.shatailConfig = window.shatailConfig || {};
    window.shatailConfig.ACTIVE_CONTENT_LOCALE = '{{ locale.language_code|escapejs }}'; { % endif %
    }
</script>
{% endblock %}