{% extends "tests/base.html" %} {% load shatailcore_tags %} {% block content %}
<p>{{ greeting }}</p>
<form action="{% pageurl self %}" method="post">
    {% csrf_token %} {{ form.as_p }}
    <input type="submit" class="button">
</form>
{% endblock %}