{% load i18n %} {% if queries %} {% if is_searching %}
<h2 role="alert">
    {% blocktrans trimmed count counter=queries|length %} There is {{ counter }} match {% plural %} There are {{ counter }} matches {% endblocktrans %}
</h2>
{% endif %} {% include "shatailsearchpromotions/list.html" %} {% include "shatailadmin/shared/pagination_nav.html" with items=queries linkurl="shatailsearchpromotions:index" %} {% else %} {% if is_searching %}
<p role="alert">{% blocktrans trimmed %}Sorry, no promoted results match "<em>{{ query_string }}</em>"{% endblocktrans %}</p>
{% else %} {% url 'shatailsearchpromotions:add' as shatailsearchpromotions_add_url %}
<p>{% blocktrans trimmed %}No promoted results have been created. Why not <a href="{{ shatailsearchpromotions_add_url }}">add one</a>?{% endblocktrans %}</p>
{% endif %} {% endif %}