{% load i18n shatailadmin_tags %} {% include "shatailadmin/shared/chooser_breadcrumb.html" with page=parent_page show_locale_labels=show_locale_labels %} {% include "shatailadmin/pages/listing/_list_choose.html" with allow_navigation=1 orderable=0 pages=pages
parent_page=parent_page show_locale_labels=show_locale_labels %} {% url 'shatailadmin_choose_page_child' parent_page.id as pagination_base_url %} {% paginate pages base_url=pagination_base_url classnames="navigate-pages" %}