{% extends "shatailadmin/shared/field.html" %} {% load i18n shatailimages_tags %} {% block form_field %} {% image image original as original_image %}

<a href="{{ original_image.url }}" class="icon icon-image">{{ image.filename }}</a> ({{ original_image.width }}x{{ original_image.height}})<br /><br /> {% trans "Change image file:" %} {{ field }} {% endblock %}