{% extends "shatailadmin/admin_base.html" %} {% load shatailadmin_tags shatailcore_tags i18n %} {% block titletag %}{% trans "Error 404: Page not found" %}{% endblock %} {% block extra_css %} {{ block.super }}

<link rel="stylesheet" href="{% versioned_static 'shatailadmin/css/layouts/404.css' %}" /> {% endblock %} {% block furniture %}
<main class="page404__bg">
    <div class="w-w-full w-h-full w-max-w-6xl w-mx-auto w-flex w-items-center w-justify-center">
        {% block branding_logo %}
        <div class="page404__logo w-hidden sm:w-block">
            <img src="{% versioned_static 'shatailadmin/images/shatail-logo.svg' %}" alt="" />
        </div>
        {% endblock %}

        <div class="page404__text-container">
            <h1 class="page404__header">
                {% trans "Error 404" %}
            </h1>

            <p class="page404__text">
                {% trans "The requested page could not be found." %}
            </p>

            <a class="page404__button button" href="{% url 'shatailadmin_home' %}">{% trans "Go to Shatail admin" %}</a>
        </div>
    </div>
</main>
{% endblock %}