{% load i18n %} {% if redirects %} {% if query_string %}
<h2 role="alert">
    {% blocktrans trimmed count counter=redirects.paginator.count %} There is {{ counter }} match {% plural %} There are {{ counter }} matches {% endblocktrans %}
</h2>
{% endif %} {% include "shatailredirects/list.html" %} {% include "shatailadmin/shared/pagination_nav.html" with items=redirects linkurl="shatailredirects:index" %} {% else %} {% if query_string %}
<p role="alert">{% blocktrans trimmed %}Sorry, no redirects match "<em>{{ query_string }}</em>"{% endblocktrans %}</p>
{% else %} {% url 'shatailredirects:add' as shatailredirects_add_redirect_url %}
<p>{% blocktrans trimmed %}No redirects have been created. Why not <a href="{{ shatailredirects_add_redirect_url }}">add one</a>?{% endblocktrans %}</p>
{% endif %} {% endif %}