{% extends "shatailadmin/base.html" %} {% load i18n %} {% block titletag %}{% blocktrans trimmed with title=redirect.title %}Editing {{ title }}{% endblocktrans %}{% endblock %} {% block content %} {% trans "Editing" as editing_str %} {% include "shatailadmin/shared/header.html"
with title=editing_str subtitle=redirect.title icon="redirect" %} {% include "shatailadmin/shared/non_field_errors.html" %}

<form action="{% url 'shatailredirects:edit' redirect.id %}" method="POST" class="nice-padding" novalidate>
    {% csrf_token %}

    <ul class="fields">
        {% for field in form.visible_fields %} {% include "shatailadmin/shared/field_as_li.html" %} {% endfor %}

        <li>
            <input type="submit" value="{% trans 'Save' %}" class="button" /> {% if user_can_delete %}
            <a href="{% url 'shatailredirects:delete' redirect.id %}" class="button button-secondary no">{% trans "Delete redirect" %}</a> {% endif %}
        </li>
    </ul>
</form>

{% endblock %} {% block extra_js %} {{ block.super }} {% include "shatailadmin/pages/_editor_js.html" %} {{ form.media.js }} {% endblock %} {% block extra_css %} {{ block.super }} {{ form.media.css }} {% endblock %}