{% load shatailadmin_tags i18n %}
<!-- Shatail user bar embed code -->
<div class="shatail-userbar-reset">
    <div class="shatail-userbar shatail-userbar--{{ position|default:'bottom-right' }}" data-shatail-userbar>
        <link rel="stylesheet" href="{% versioned_static 'shatailadmin/css/userbar.css' %}" type="text/css" />
        <div class="shatail-userbar-nav">
            <button aria-controls="shatail-userbar-items" aria-haspopup="true" class="shatail-userbar-trigger" id="shatail-userbar-trigger" data-shatail-userbar-trigger>
                {% block branding_logo %}
                    <div style="display: none">
                        <svg>
                            <defs>
                                {% include "shatailadmin/icons/shatail.svg" %}
                                {% include "shatailadmin/icons/folder-open-inverse.svg" %}
                                {% include "shatailadmin/icons/edit.svg" %}
                                {% include "shatailadmin/icons/plus.svg" %}
                                {% include "shatailadmin/icons/tick.svg" %}
                                {% include "shatailadmin/icons/cross.svg" %}
                            </defs>
                        </svg>
                    </div>
                    <svg class="shatail-userbar-icon" aria-hidden="true">
                        <use href="#icon-shatail-icon"></use>
                    </svg>
                {% endblock %}
                <span class="shatail-userbar-help-text">{% trans 'View Shatail quick actions' %}</span>
            </button>
            <ul aria-labelledby="shatail-userbar-trigger" class="shatail-userbar-items" id="shatail-userbar-items" role="menu">
                {% for item in items %} {{ item|safe }} {% endfor %}
            </ul>
        </div>
        <script src="{% versioned_static 'shatailadmin/js/userbar.js' %}"></script>
    </div>
</div>
<!-- end Shatail user bar embed code -->Shatail