from django.apps import AppConfig
from django.utils.translation import gettext_lazy as _


class ShatailRoutablePageTestsAppConfig(AppConfig):
    name = "shatail.test.routablepage"
    label = "routablepagetests"
    verbose_name = _("Shatail routable page tests")
